Class: Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Next ID: 9

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRule

Returns a new instance of CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRule.



89
90
91
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 89

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#child_alignment_ruleGoogle::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleChildAlignmentRule

A rule that aligns specified child fields with a parent field. Corresponds to the JSON property childAlignmentRule



52
53
54
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 52

def child_alignment_rule
  @child_alignment_rule
end

#descriptionString

Description of the validation rule. This has no use but for documentation Corresponds to the JSON property description

Returns:

  • (String)


57
58
59
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 57

def description
  @description
end

#entity_alignment_ruleGoogle::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleEntityAlignmentRule

A rule that aligns specified fields with each other. Corresponds to the JSON property entityAlignmentRule



62
63
64
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 62

def entity_alignment_rule
  @entity_alignment_rule
end

#field_occurrencesGoogle::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFieldOccurrences

Corresponds to the JSON property fieldOccurrences



67
68
69
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 67

def field_occurrences
  @field_occurrences
end

#field_regexGoogle::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFieldRegex

Corresponds to the JSON property fieldRegex



72
73
74
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 72

def field_regex
  @field_regex
end

#form_validationGoogle::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidation

Corresponds to the JSON property formValidation



77
78
79
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 77

def form_validation
  @form_validation
end

#nameString

Name of the validation rule. Corresponds to the JSON property name

Returns:

  • (String)


82
83
84
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 82

def name
  @name
end

#rule_idString

Unique identifier of the rule. Optional. Corresponds to the JSON property ruleId

Returns:

  • (String)


87
88
89
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 87

def rule_id
  @rule_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



94
95
96
97
98
99
100
101
102
103
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 94

def update!(**args)
  @child_alignment_rule = args[:child_alignment_rule] if args.key?(:child_alignment_rule)
  @description = args[:description] if args.key?(:description)
  @entity_alignment_rule = args[:entity_alignment_rule] if args.key?(:entity_alignment_rule)
  @field_occurrences = args[:field_occurrences] if args.key?(:field_occurrences)
  @field_regex = args[:field_regex] if args.key?(:field_regex)
  @form_validation = args[:form_validation] if args.key?(:form_validation)
  @name = args[:name] if args.key?(:name)
  @rule_id = args[:rule_id] if args.key?(:rule_id)
end