Class: Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidation
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Instance Attribute Summary collapse
-
#left_operand ⇒ Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation
Corresponds to the JSON property
leftOperand. -
#right_operand ⇒ Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation
Corresponds to the JSON property
rightOperand. -
#validation_operator ⇒ String
The relational operator to be applied to the operands.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidation
constructor
A new instance of CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidation
Returns a new instance of CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidation.
317 318 319 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#left_operand ⇒ Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation
Corresponds to the JSON property leftOperand
305 306 307 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 305 def left_operand @left_operand end |
#right_operand ⇒ Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation
Corresponds to the JSON property rightOperand
310 311 312 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 310 def right_operand @right_operand end |
#validation_operator ⇒ String
The relational operator to be applied to the operands.
Corresponds to the JSON property validationOperator
315 316 317 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 315 def validation_operator @validation_operator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
322 323 324 325 326 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 322 def update!(**args) @left_operand = args[:left_operand] if args.key?(:left_operand) @right_operand = args[:right_operand] if args.key?(:right_operand) @validation_operator = args[:validation_operator] if args.key?(:validation_operator) end |