Class: Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation

Returns a new instance of CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation.



353
354
355
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constantsArray<Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleConstant>

A list of constants to be used as operands. Corresponds to the JSON property constants



336
337
338
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 336

def constants
  @constants
end

#fieldsArray<Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleField>

A list of fields to be used as operands. Corresponds to the JSON property fields



341
342
343
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 341

def fields
  @fields
end

#operation_typeString

The operation type to be applied to all the operands. Corresponds to the JSON property operationType

Returns:

  • (String)


346
347
348
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 346

def operation_type
  @operation_type
end

#operationsArray<Google::Apis::DocumentaiV1beta3::CloudAiDocumentaiLabHifiaToolsValidationValidatorInputValidationRuleFormValidationOperation>

A list of recursive operations to be used as operands. Corresponds to the JSON property operations



351
352
353
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 351

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



358
359
360
361
362
363
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 358

def update!(**args)
  @constants = args[:constants] if args.key?(:constants)
  @fields = args[:fields] if args.key?(:fields)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @operations = args[:operations] if args.key?(:operations)
end