Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsMetadataIndividualBatchUpdateStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The status of each individual document in the batch update process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsMetadataIndividualBatchUpdateStatus

Returns a new instance of GoogleCloudDocumentaiUiv1beta3BatchUpdateDocumentsMetadataIndividualBatchUpdateStatus.



644
645
646
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_idGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentId

Document Identifier. Corresponds to the JSON property documentId



632
633
634
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 632

def document_id
  @document_id
end

#statusGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



642
643
644
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 642

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



649
650
651
652
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 649

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @status = args[:status] if args.key?(:status)
end