Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The common metadata for long running operations.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation time of the operation.
-
#resource ⇒ String
A related resource to this operation.
-
#state ⇒ String
The state of the operation.
-
#state_message ⇒ String
A message providing more details about the current state of processing.
-
#update_time ⇒ String
The last update time of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata
Returns a new instance of GoogleCloudDocumentaiUiv1beta3CommonOperationMetadata.
697 698 699 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation time of the operation.
Corresponds to the JSON property createTime
675 676 677 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 675 def create_time @create_time end |
#resource ⇒ String
A related resource to this operation.
Corresponds to the JSON property resource
680 681 682 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 680 def resource @resource end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
685 686 687 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 685 def state @state end |
#state_message ⇒ String
A message providing more details about the current state of processing.
Corresponds to the JSON property stateMessage
690 691 692 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 690 def @state_message end |
#update_time ⇒ String
The last update time of the operation.
Corresponds to the JSON property updateTime
695 696 697 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 695 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
702 703 704 705 706 707 708 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 702 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @resource = args[:resource] if args.key?(:resource) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @update_time = args[:update_time] if args.key?(:update_time) end |