Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

EntityType is the wrapper of a label of the corresponding model with detailed attributes and limitations for entity-based processors. Multiple types can also compose a dependency tree to represent nested types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityType

Returns a new instance of GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityType.



1026
1027
1028
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_typesArray<String>

The entity type that this type is derived from. For now, one and only one should be set. Corresponds to the JSON property baseTypes

Returns:

  • (Array<String>)


986
987
988
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 986

def base_types
  @base_types
end

#descriptionString

The description of the entity type. Could be used to provide more information about the entity type for model calls. Corresponds to the JSON property description

Returns:

  • (String)


992
993
994
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 992

def description
  @description
end

#display_nameString

User defined name for the type. Corresponds to the JSON property displayName

Returns:

  • (String)


997
998
999
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 997

def display_name
  @display_name
end

#entity_type_metadataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3EntityTypeMetadata

Metadata about an entity type. Corresponds to the JSON property entityTypeMetadata



1002
1003
1004
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1002

def 
  @entity_type_metadata
end

#enum_valuesGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityTypeEnumValues

Defines the a list of enum values. Corresponds to the JSON property enumValues



1007
1008
1009
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1007

def enum_values
  @enum_values
end

#nameString

Name of the type. It must be unique within the schema file and cannot be a " Common Type". The following naming conventions are used: - Use snake_casing.

  • Name matching is case-sensitive. - Maximum 64 characters. - Must start with a letter. - Allowed characters: ASCII letters [a-z0-9_-]. (For backward compatibility internal infrastructure and tooling can handle any ascii character.) - The / is sometimes used to denote a property of a type. For example line_item/amount. This convention is deprecated, but will still be honored for backward compatibility. Corresponds to the JSON property name

Returns:

  • (String)


1019
1020
1021
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1019

def name
  @name
end

#propertiesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityTypeProperty>

Description the nested structure, or composition of an entity. Corresponds to the JSON property properties



1024
1025
1026
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1024

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1031
1032
1033
1034
1035
1036
1037
1038
1039
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1031

def update!(**args)
  @base_types = args[:base_types] if args.key?(:base_types)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_type_metadata = args[:entity_type_metadata] if args.key?(:entity_type_metadata)
  @enum_values = args[:enum_values] if args.key?(:enum_values)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end