Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityTypeProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Defines properties that can be part of the entity type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityTypeProperty

Returns a new instance of GoogleCloudDocumentaiUiv1beta3DocumentSchemaEntityTypeProperty.



1103
1104
1105
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the property. Could be used to provide more information about the property for model calls. Corresponds to the JSON property description

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1069

def description
  @description
end

#display_nameString

User defined name for the property. Corresponds to the JSON property displayName

Returns:

  • (String)


1074
1075
1076
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1074

def display_name
  @display_name
end

#method_propString

Specifies how the entity's value is obtained. Corresponds to the JSON property method

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1079

def method_prop
  @method_prop
end

#nameString

The name of the property. Follows the same guidelines as the EntityType name. Corresponds to the JSON property name

Returns:

  • (String)


1084
1085
1086
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1084

def name
  @name
end

#occurrence_typeString

Occurrence type limits the number of instances an entity type appears in the document. Corresponds to the JSON property occurrenceType

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1090

def occurrence_type
  @occurrence_type
end

#property_metadataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3PropertyMetadata

Metadata about a property. Corresponds to the JSON property propertyMetadata



1095
1096
1097
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1095

def 
  @property_metadata
end

#value_typeString

A reference to the value type of the property. This type is subject to the same conventions as the Entity.base_types field. Corresponds to the JSON property valueType

Returns:

  • (String)


1101
1102
1103
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1101

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1108
1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1108

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @name = args[:name] if args.key?(:name)
  @occurrence_type = args[:occurrence_type] if args.key?(:occurrence_type)
  @property_metadata = args[:property_metadata] if args.key?(:property_metadata)
  @value_type = args[:value_type] if args.key?(:value_type)
end