Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchemaMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchemaMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Metadata for global schema behavior.
Instance Attribute Summary collapse
-
#document_allow_multiple_labels ⇒ Boolean
(also: #document_allow_multiple_labels?)
If true, on a given page, there can be multiple
documentannotations covering it. -
#document_splitter ⇒ Boolean
(also: #document_splitter?)
If true, a
documententity type can be applied to subdocument (splitting). -
#prefixed_naming_on_properties ⇒ Boolean
(also: #prefixed_naming_on_properties?)
If set, all the nested entities must be prefixed with the parents.
-
#skip_naming_validation ⇒ Boolean
(also: #skip_naming_validation?)
If set, we will skip the naming format validation in the schema.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3DocumentSchemaMetadata
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3DocumentSchemaMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3DocumentSchemaMetadata
Returns a new instance of GoogleCloudDocumentaiUiv1beta3DocumentSchemaMetadata.
1151 1152 1153 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_allow_multiple_labels ⇒ Boolean Also known as: document_allow_multiple_labels?
If true, on a given page, there can be multiple document annotations
covering it.
Corresponds to the JSON property documentAllowMultipleLabels
1127 1128 1129 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1127 def document_allow_multiple_labels @document_allow_multiple_labels end |
#document_splitter ⇒ Boolean Also known as: document_splitter?
If true, a document entity type can be applied to subdocument (splitting).
Otherwise, it can only be applied to the entire document (classification).
Corresponds to the JSON property documentSplitter
1134 1135 1136 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1134 def document_splitter @document_splitter end |
#prefixed_naming_on_properties ⇒ Boolean Also known as: prefixed_naming_on_properties?
If set, all the nested entities must be prefixed with the parents.
Corresponds to the JSON property prefixedNamingOnProperties
1140 1141 1142 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1140 def prefixed_naming_on_properties @prefixed_naming_on_properties end |
#skip_naming_validation ⇒ Boolean Also known as: skip_naming_validation?
If set, we will skip the naming format validation in the schema. So the string
values in DocumentSchema.EntityType.name and DocumentSchema.EntityType.
Property.name will not be checked.
Corresponds to the JSON property skipNamingValidation
1148 1149 1150 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1148 def skip_naming_validation @skip_naming_validation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1156 1157 1158 1159 1160 1161 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1156 def update!(**args) @document_allow_multiple_labels = args[:document_allow_multiple_labels] if args.key?(:document_allow_multiple_labels) @document_splitter = args[:document_splitter] if args.key?(:document_splitter) @prefixed_naming_on_properties = args[:prefixed_naming_on_properties] if args.key?(:prefixed_naming_on_properties) @skip_naming_validation = args[:skip_naming_validation] if args.key?(:skip_naming_validation) end |