Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3EntityTypeMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Metadata about an entity type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3EntityTypeMetadata

Returns a new instance of GoogleCloudDocumentaiUiv1beta3EntityTypeMetadata.



1234
1235
1236
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_tier_metadataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3FieldTierMetadata

Metadata for the field tier of a property. Corresponds to the JSON property fieldTierMetadata



1204
1205
1206
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1204

def 
  @field_tier_metadata
end

#human_review_labeling_metadataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewLabelingMetadata

Metadata for human review labeling config. Corresponds to the JSON property humanReviewLabelingMetadata



1209
1210
1211
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1209

def 
  @human_review_labeling_metadata
end

#human_review_metadataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata

Metadata for Human Review config. Corresponds to the JSON property humanReviewMetadata



1214
1215
1216
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1214

def 
  @human_review_metadata
end

#inactiveBoolean Also known as: inactive?

Whether the entity type should be considered inactive. Corresponds to the JSON property inactive

Returns:

  • (Boolean)


1219
1220
1221
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1219

def inactive
  @inactive
end

#schema_editability_metadataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SchemaEditabilityMetadata

Metadata that specifies whether a label is editable and reasons why. These fields are read-only. Changing these fields has no impact on the backend. Corresponds to the JSON property schemaEditabilityMetadata



1226
1227
1228
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1226

def 
  @schema_editability_metadata
end

#schema_inference_metadataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SchemaInferenceMetadata

Metadata for schema inference. Only used on dataset.schema for schema inference, can be safely ignored elsewhere. Corresponds to the JSON property schemaInferenceMetadata



1232
1233
1234
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1232

def 
  @schema_inference_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1239
1240
1241
1242
1243
1244
1245
1246
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1239

def update!(**args)
  @field_tier_metadata = args[:field_tier_metadata] if args.key?(:field_tier_metadata)
  @human_review_labeling_metadata = args[:human_review_labeling_metadata] if args.key?(:human_review_labeling_metadata)
  @human_review_metadata = args[:human_review_metadata] if args.key?(:human_review_metadata)
  @inactive = args[:inactive] if args.key?(:inactive)
  @schema_editability_metadata = args[:schema_editability_metadata] if args.key?(:schema_editability_metadata)
  @schema_inference_metadata = args[:schema_inference_metadata] if args.key?(:schema_inference_metadata)
end