Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3EvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3EvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Evaluation metrics, either in aggregate or about a specific entity.
Instance Attribute Summary collapse
-
#f1_score ⇒ Float
The calculated f1 score.
-
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
-
#false_positives_count ⇒ Fixnum
The amount of false positives.
-
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
-
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
-
#precision ⇒ Float
The calculated precision.
-
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
-
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
-
#recall ⇒ Float
The calculated recall.
-
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
-
#true_positives_count ⇒ Fixnum
The amount of true positives.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3EvaluationMetrics
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3EvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3EvaluationMetrics
Returns a new instance of GoogleCloudDocumentaiUiv1beta3EvaluationMetrics.
1346 1347 1348 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#f1_score ⇒ Float
The calculated f1 score.
Corresponds to the JSON property f1Score
1294 1295 1296 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1294 def f1_score @f1_score end |
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
Corresponds to the JSON property falseNegativesCount
1299 1300 1301 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1299 def false_negatives_count @false_negatives_count end |
#false_positives_count ⇒ Fixnum
The amount of false positives.
Corresponds to the JSON property falsePositivesCount
1304 1305 1306 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1304 def false_positives_count @false_positives_count end |
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
Corresponds to the JSON property groundTruthDocumentCount
1309 1310 1311 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1309 def ground_truth_document_count @ground_truth_document_count end |
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
Corresponds to the JSON property groundTruthOccurrencesCount
1314 1315 1316 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1314 def ground_truth_occurrences_count @ground_truth_occurrences_count end |
#precision ⇒ Float
The calculated precision.
Corresponds to the JSON property precision
1319 1320 1321 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1319 def precision @precision end |
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
Corresponds to the JSON property predictedDocumentCount
1324 1325 1326 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1324 def predicted_document_count @predicted_document_count end |
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
Corresponds to the JSON property predictedOccurrencesCount
1329 1330 1331 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1329 def predicted_occurrences_count @predicted_occurrences_count end |
#recall ⇒ Float
The calculated recall.
Corresponds to the JSON property recall
1334 1335 1336 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1334 def recall @recall end |
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
Corresponds to the JSON property totalDocumentsCount
1339 1340 1341 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1339 def total_documents_count @total_documents_count end |
#true_positives_count ⇒ Fixnum
The amount of true positives.
Corresponds to the JSON property truePositivesCount
1344 1345 1346 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1344 def true_positives_count @true_positives_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1351 def update!(**args) @f1_score = args[:f1_score] if args.key?(:f1_score) @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count) @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count) @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count) @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count) @precision = args[:precision] if args.key?(:precision) @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count) @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count) @recall = args[:recall] if args.key?(:recall) @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count) @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count) end |