Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadataIndividualExportStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The status of each individual document in the export process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadataIndividualExportStatus

Returns a new instance of GoogleCloudDocumentaiUiv1beta3ExportDocumentsMetadataIndividualExportStatus.



1459
1460
1461
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_idGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentId

Document Identifier. Corresponds to the JSON property documentId



1441
1442
1443
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1441

def document_id
  @document_id
end

#output_gcs_destinationString

The output_gcs_destination of the exported document if it was successful, otherwise empty. Corresponds to the JSON property outputGcsDestination

Returns:

  • (String)


1447
1448
1449
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1447

def output_gcs_destination
  @output_gcs_destination
end

#statusGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



1457
1458
1459
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1457

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1464
1465
1466
1467
1468
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1464

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @output_gcs_destination = args[:output_gcs_destination] if args.key?(:output_gcs_destination)
  @status = args[:status] if args.key?(:status)
end