Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3FieldTierMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Metadata for the field tier of a property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3FieldTierMetadata

Returns a new instance of GoogleCloudDocumentaiUiv1beta3FieldTierMetadata.



1604
1605
1606
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tier_levelFixnum

Integer that indicates the tier of a property. e.g. Invoice has entities that are classified as tier 1 which is the most important, while tier 2 and tier 3 less so. This attribute can be used to filter schema attributes before running eval. e.g. compute F1 score for only tier 1 entities. If not present this attribute should be inferred as 1. Corresponds to the JSON property tierLevel

Returns:

  • (Fixnum)


1602
1603
1604
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1602

def tier_level
  @tier_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1609
1610
1611
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1609

def update!(**args)
  @tier_level = args[:tier_level] if args.key?(:tier_level)
end