Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Metadata for Human Review config.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The confidence threshold if human review validation is enabled.
-
#enable_validation ⇒ Boolean
(also: #enable_validation?)
Whether to enable human review validation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata
Returns a new instance of GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata.
1649 1650 1651 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The confidence threshold if human review validation is enabled.
Corresponds to the JSON property confidenceThreshold
1641 1642 1643 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1641 def confidence_threshold @confidence_threshold end |
#enable_validation ⇒ Boolean Also known as: enable_validation?
Whether to enable human review validation.
Corresponds to the JSON property enableValidation
1646 1647 1648 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1646 def enable_validation @enable_validation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1654 1655 1656 1657 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1654 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @enable_validation = args[:enable_validation] if args.key?(:enable_validation) end |