Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataImportConfigValidationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The validation status of each import config. Status is set to an error if there are no documents to import in the import_config, or OK if the operation will try to proceed with at least one document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataImportConfigValidationResult

Returns a new instance of GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataImportConfigValidationResult.



1718
1719
1720
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_gcs_sourceString

The source Cloud Storage URI specified in the import config. Corresponds to the JSON property inputGcsSource

Returns:

  • (String)


1706
1707
1708
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1706

def input_gcs_source
  @input_gcs_source
end

#statusGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



1716
1717
1718
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1716

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1723
1724
1725
1726
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1723

def update!(**args)
  @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source)
  @status = args[:status] if args.key?(:status)
end