Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3Processor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3Processor

Returns a new instance of GoogleCloudDocumentaiUiv1beta3Processor.



1896
1897
1898
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_schema_versionString

Optional. SchemaVersion used by the Processor. It is the same as Processor's DatasetSchema.schema_version Format is projects/project/locations/location /schemas/schema/schemaVersions/schema_version Corresponds to the JSON propertyactiveSchemaVersion`

Returns:

  • (String)


1833
1834
1835
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1833

def active_schema_version
  @active_schema_version
end

#create_timeString

Output only. The time the processor was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1838
1839
1840
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1838

def create_time
  @create_time
end

#default_processor_versionString

The default processor version. Corresponds to the JSON property defaultProcessorVersion

Returns:

  • (String)


1843
1844
1845
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1843

def default_processor_version
  @default_processor_version
end

#display_nameString

The display name of the processor. Corresponds to the JSON property displayName

Returns:

  • (String)


1848
1849
1850
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1848

def display_name
  @display_name
end

#kms_key_nameString

The KMS key used for encryption and decryption in CMEK scenarios. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


1854
1855
1856
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1854

def kms_key_name
  @kms_key_name
end

#nameString

Output only. Immutable. The resource name of the processor. Format: projects/ project/locations/location/processors/processor` Corresponds to the JSON propertyname`

Returns:

  • (String)


1860
1861
1862
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1860

def name
  @name
end

#process_endpointString

Output only. Immutable. The http endpoint that can be called to invoke processing. Corresponds to the JSON property processEndpoint

Returns:

  • (String)


1866
1867
1868
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1866

def process_endpoint
  @process_endpoint
end

#processor_version_aliasesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionAlias>

Output only. The processor version aliases. Corresponds to the JSON property processorVersionAliases



1871
1872
1873
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1871

def processor_version_aliases
  @processor_version_aliases
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1876
1877
1878
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1876

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1882
1883
1884
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1882

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The state of the processor. Corresponds to the JSON property state

Returns:

  • (String)


1888
1889
1890
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1888

def state
  @state
end

#typeString

The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR. To get a list of processor types, see FetchProcessorTypes. Corresponds to the JSON property type

Returns:

  • (String)


1894
1895
1896
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1894

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1901

def update!(**args)
  @active_schema_version = args[:active_schema_version] if args.key?(:active_schema_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_processor_version = args[:default_processor_version] if args.key?(:default_processor_version)
  @display_name = args[:display_name] if args.key?(:display_name)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @name = args[:name] if args.key?(:name)
  @process_endpoint = args[:process_endpoint] if args.key?(:process_endpoint)
  @processor_version_aliases = args[:processor_version_aliases] if args.key?(:processor_version_aliases)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end