Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersion
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deployment_allowed ⇒ Boolean
(also: #deployment_allowed?)
Output only.
-
#deprecation_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionDeprecationInfo
Information about the upcoming deprecation of this processor version.
-
#display_name ⇒ String
The display name of the processor version.
-
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
-
#gen_ai_model_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfo
Information about Generative AI model-based processor versions.
-
#google_managed ⇒ Boolean
(also: #google_managed?)
Output only.
-
#kms_key_name ⇒ String
Output only.
-
#kms_key_version_name ⇒ String
Output only.
-
#latest_evaluation ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3EvaluationReference
Gives a short summary of an evaluation, and links to the evaluation itself.
-
#model_type ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3Schema
The schema defines the output of the processed document by a processor.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ProcessorVersion
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3ProcessorVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ProcessorVersion
Returns a new instance of GoogleCloudDocumentaiUiv1beta3ProcessorVersion.
2011 2012 2013 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the processor version was created.
Corresponds to the JSON property createTime
1927 1928 1929 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1927 def create_time @create_time end |
#deployment_allowed ⇒ Boolean Also known as: deployment_allowed?
Output only. Denotes that this ProcessorVersion can be deployed and
undeployed.
Corresponds to the JSON property deploymentAllowed
1933 1934 1935 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1933 def deployment_allowed @deployment_allowed end |
#deprecation_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionDeprecationInfo
Information about the upcoming deprecation of this processor version.
Corresponds to the JSON property deprecationInfo
1939 1940 1941 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1939 def deprecation_info @deprecation_info end |
#display_name ⇒ String
The display name of the processor version.
Corresponds to the JSON property displayName
1944 1945 1946 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1944 def display_name @display_name end |
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property documentSchema
1949 1950 1951 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1949 def document_schema @document_schema end |
#gen_ai_model_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfo
Information about Generative AI model-based processor versions.
Corresponds to the JSON property genAiModelInfo
1954 1955 1956 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1954 def gen_ai_model_info @gen_ai_model_info end |
#google_managed ⇒ Boolean Also known as: google_managed?
Output only. Denotes that this ProcessorVersion is managed by Google.
Corresponds to the JSON property googleManaged
1959 1960 1961 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1959 def google_managed @google_managed end |
#kms_key_name ⇒ String
Output only. The KMS key name used for encryption.
Corresponds to the JSON property kmsKeyName
1965 1966 1967 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1965 def kms_key_name @kms_key_name end |
#kms_key_version_name ⇒ String
Output only. The KMS key version with which data is encrypted.
Corresponds to the JSON property kmsKeyVersionName
1970 1971 1972 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1970 def kms_key_version_name @kms_key_version_name end |
#latest_evaluation ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3EvaluationReference
Gives a short summary of an evaluation, and links to the evaluation itself.
Corresponds to the JSON property latestEvaluation
1975 1976 1977 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1975 def latest_evaluation @latest_evaluation end |
#model_type ⇒ String
Output only. The model type of this processor version.
Corresponds to the JSON property modelType
1980 1981 1982 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1980 def model_type @model_type end |
#name ⇒ String
Identifier. The resource name of the processor version. Format: projects/
project/locations/location/processors/processor/processorVersions/
processor_version`
Corresponds to the JSON propertyname`
1987 1988 1989 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1987 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1992 1993 1994 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1992 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1998 1999 2000 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1998 def satisfies_pzs @satisfies_pzs end |
#schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3Schema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property schema
2004 2005 2006 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2004 def schema @schema end |
#state ⇒ String
Output only. The state of the processor version.
Corresponds to the JSON property state
2009 2010 2011 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2009 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2016 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deployment_allowed = args[:deployment_allowed] if args.key?(:deployment_allowed) @deprecation_info = args[:deprecation_info] if args.key?(:deprecation_info) @display_name = args[:display_name] if args.key?(:display_name) @document_schema = args[:document_schema] if args.key?(:document_schema) @gen_ai_model_info = args[:gen_ai_model_info] if args.key?(:gen_ai_model_info) @google_managed = args[:google_managed] if args.key?(:google_managed) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_version_name = args[:kms_key_version_name] if args.key?(:kms_key_version_name) @latest_evaluation = args[:latest_evaluation] if args.key?(:latest_evaluation) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @schema = args[:schema] if args.key?(:schema) @state = args[:state] if args.key?(:state) end |