Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataDatasetResyncStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Resync status against inconsistency types on the dataset level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataDatasetResyncStatus

Returns a new instance of GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataDatasetResyncStatus.



2277
2278
2279
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_inconsistency_typeString

The type of the inconsistency of the dataset. Corresponds to the JSON property datasetInconsistencyType

Returns:

  • (String)


2265
2266
2267
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2265

def dataset_inconsistency_type
  @dataset_inconsistency_type
end

#statusGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



2275
2276
2277
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2275

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2282
2283
2284
2285
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2282

def update!(**args)
  @dataset_inconsistency_type = args[:dataset_inconsistency_type] if args.key?(:dataset_inconsistency_type)
  @status = args[:status] if args.key?(:status)
end