Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Response of the sample documents operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponse

Returns a new instance of GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponse.



2418
2419
2420
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sample_test_statusGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property sampleTestStatus



2401
2402
2403
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2401

def sample_test_status
  @sample_test_status
end

#sample_training_statusGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property sampleTrainingStatus



2411
2412
2413
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2411

def sample_training_status
  @sample_training_status
end

#selected_documentsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SampleDocumentsResponseSelectedDocument>

The result of the sampling process. Corresponds to the JSON property selectedDocuments



2416
2417
2418
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2416

def selected_documents
  @selected_documents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2423
2424
2425
2426
2427
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2423

def update!(**args)
  @sample_test_status = args[:sample_test_status] if args.key?(:sample_test_status)
  @sample_training_status = args[:sample_training_status] if args.key?(:sample_training_status)
  @selected_documents = args[:selected_documents] if args.key?(:selected_documents)
end