Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SchemaEditabilityMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Metadata that specifies whether a label is editable and reasons why. These fields are read-only. Changing these fields has no impact on the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3SchemaEditabilityMetadata

Returns a new instance of GoogleCloudDocumentaiUiv1beta3SchemaEditabilityMetadata.



2498
2499
2500
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editableBoolean Also known as: editable?

Explicit flag that controls whether the label is editable. Corresponds to the JSON property editable

Returns:

  • (Boolean)


2488
2489
2490
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2488

def editable
  @editable
end

#processor_versionsArray<String>

Full resource name of processor versions that contain this label. e.g. projects/project/locations/location/processors/processor/ processorVersions/processorVersion` Corresponds to the JSON propertyprocessorVersions`

Returns:

  • (Array<String>)


2496
2497
2498
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2496

def processor_versions
  @processor_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2503
2504
2505
2506
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2503

def update!(**args)
  @editable = args[:editable] if args.key?(:editable)
  @processor_versions = args[:processor_versions] if args.key?(:processor_versions)
end