Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The dataset validation information. This includes any and all errors with documents and the dataset.
Instance Attribute Summary collapse
-
#dataset_error_count ⇒ Fixnum
The total number of dataset errors.
-
#dataset_errors ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleRpcStatus>
Error information for the dataset as a whole.
-
#document_error_count ⇒ Fixnum
The total number of document errors.
-
#document_errors ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleRpcStatus>
Error information pertaining to specific documents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation
Returns a new instance of GoogleCloudDocumentaiUiv1beta3TrainProcessorVersionMetadataDatasetValidation.
2736 2737 2738 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_error_count ⇒ Fixnum
The total number of dataset errors.
Corresponds to the JSON property datasetErrorCount
2716 2717 2718 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2716 def dataset_error_count @dataset_error_count end |
#dataset_errors ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleRpcStatus>
Error information for the dataset as a whole. A maximum of 10 dataset errors
will be returned. A single dataset error is terminal for training.
Corresponds to the JSON property datasetErrors
2722 2723 2724 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2722 def dataset_errors @dataset_errors end |
#document_error_count ⇒ Fixnum
The total number of document errors.
Corresponds to the JSON property documentErrorCount
2727 2728 2729 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2727 def document_error_count @document_error_count end |
#document_errors ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleRpcStatus>
Error information pertaining to specific documents. A maximum of 10 document
errors will be returned. Any document with errors will not be used throughout
training.
Corresponds to the JSON property documentErrors
2734 2735 2736 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2734 def document_errors @document_errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2741 2742 2743 2744 2745 2746 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2741 def update!(**args) @dataset_error_count = args[:dataset_error_count] if args.key?(:dataset_error_count) @dataset_errors = args[:dataset_errors] if args.key?(:dataset_errors) @document_error_count = args[:document_error_count] if args.key?(:document_error_count) @document_errors = args[:document_errors] if args.key?(:document_errors) end |