Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1BatchProcessMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The long-running operation metadata for BatchProcessDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1BatchProcessMetadata

Returns a new instance of GoogleCloudDocumentaiV1BatchProcessMetadata.



2907
2908
2909
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The creation time of the operation. Corresponds to the JSON property createTime

Returns:

  • (String)


2884
2885
2886
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2884

def create_time
  @create_time
end

#individual_process_statusesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus>

The list of response details of each document. Corresponds to the JSON property individualProcessStatuses



2889
2890
2891
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2889

def individual_process_statuses
  @individual_process_statuses
end

#stateString

The state of the current batch processing. Corresponds to the JSON property state

Returns:

  • (String)


2894
2895
2896
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2894

def state
  @state
end

#state_messageString

A message providing more details about the current state of processing. For example, the error message if the operation is failed. Corresponds to the JSON property stateMessage

Returns:

  • (String)


2900
2901
2902
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2900

def state_message
  @state_message
end

#update_timeString

The last update time of the operation. Corresponds to the JSON property updateTime

Returns:

  • (String)


2905
2906
2907
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2905

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2912
2913
2914
2915
2916
2917
2918
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2912

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @individual_process_statuses = args[:individual_process_statuses] if args.key?(:individual_process_statuses)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @update_time = args[:update_time] if args.key?(:update_time)
end