Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1ReviewDocumentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Response message for the ReviewDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ReviewDocumentResponse

Returns a new instance of GoogleCloudDocumentaiV1ReviewDocumentResponse.



3275
3276
3277
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_destinationString

The Cloud Storage uri for the human reviewed document if the review is succeeded. Corresponds to the JSON property gcsDestination

Returns:

  • (String)


3263
3264
3265
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3263

def gcs_destination
  @gcs_destination
end

#rejection_reasonString

The reason why the review is rejected by reviewer. Corresponds to the JSON property rejectionReason

Returns:

  • (String)


3268
3269
3270
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3268

def rejection_reason
  @rejection_reason
end

#stateString

The state of the review operation. Corresponds to the JSON property state

Returns:

  • (String)


3273
3274
3275
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3273

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3280
3281
3282
3283
3284
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3280

def update!(**args)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason)
  @state = args[:state] if args.key?(:state)
end