Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The message for input config in batch process.
Instance Attribute Summary collapse
-
#gcs_source ⇒ String
The Cloud Storage location as the source of the document.
-
#mime_type ⇒ String
An IANA published media type (MIME type) of the input.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig
constructor
A new instance of GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig
Returns a new instance of GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig.
3833 3834 3835 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_source ⇒ String
The Cloud Storage location as the source of the document.
Corresponds to the JSON property gcsSource
3822 3823 3824 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3822 def gcs_source @gcs_source end |
#mime_type ⇒ String
An IANA published media type (MIME type) of the input. If the input is a raw document,
refer to supported file types for the list of media types. If the input is a Document, the type
should be application/json.
Corresponds to the JSON property mimeType
3831 3832 3833 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3831 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3838 3839 3840 3841 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3838 def update!(**args) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @mime_type = args[:mime_type] if args.key?(:mime_type) end |