Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The common metadata for long running operations.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation time of the operation.
-
#resource ⇒ String
A related resource to this operation.
-
#state ⇒ String
The state of the operation.
-
#state_message ⇒ String
A message providing more details about the current state of processing.
-
#update_time ⇒ String
The last update time of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3CommonOperationMetadata
constructor
A new instance of GoogleCloudDocumentaiV1beta3CommonOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3CommonOperationMetadata
Returns a new instance of GoogleCloudDocumentaiV1beta3CommonOperationMetadata.
3930 3931 3932 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation time of the operation.
Corresponds to the JSON property createTime
3908 3909 3910 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3908 def create_time @create_time end |
#resource ⇒ String
A related resource to this operation.
Corresponds to the JSON property resource
3913 3914 3915 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3913 def resource @resource end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
3918 3919 3920 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3918 def state @state end |
#state_message ⇒ String
A message providing more details about the current state of processing.
Corresponds to the JSON property stateMessage
3923 3924 3925 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3923 def @state_message end |
#update_time ⇒ String
The last update time of the operation.
Corresponds to the JSON property updateTime
3928 3929 3930 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3928 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3935 3936 3937 3938 3939 3940 3941 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3935 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @resource = args[:resource] if args.key?(:resource) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @update_time = args[:update_time] if args.key?(:update_time) end |