Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DatasetSchema
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DatasetSchema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Dataset Schema.
Instance Attribute Summary collapse
-
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
-
#name ⇒ String
Dataset schema resource name.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DatasetSchema
constructor
A new instance of GoogleCloudDocumentaiV1beta3DatasetSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DatasetSchema
Returns a new instance of GoogleCloudDocumentaiV1beta3DatasetSchema.
4081 4082 4083 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property documentSchema
4061 4062 4063 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4061 def document_schema @document_schema end |
#name ⇒ String
Dataset schema resource name. Format: projects/project/locations/location/
processors/processor/dataset/datasetSchema
Corresponds to the JSON property name
4067 4068 4069 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4067 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
4072 4073 4074 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4072 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
4078 4079 4080 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4078 def satisfies_pzs @satisfies_pzs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4086 4087 4088 4089 4090 4091 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4086 def update!(**args) @document_schema = args[:document_schema] if args.key?(:document_schema) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) end |