Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality.
Instance Attribute Summary collapse
-
#blob_assets ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentBlobAsset>
Optional.
-
#chunked_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocument
Represents the chunks that the document is divided into.
-
#content ⇒ String
Optional.
-
#docid ⇒ String
Optional.
-
#document_layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayout
Represents the parsed layout of a document as a collection of blocks that the document is divided into.
-
#entities ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntity>
A list of entities detected on Document.text.
-
#entities_revision_id ⇒ String
The entity revision ID that
document.entitiesfield is based on. -
#entities_revisions ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntitiesRevision>
A list of entity revisions.
-
#entity_relations ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityRelation>
Placeholder.
-
#entity_validation_output ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutput
The output of the validation given the document and the validation rules.
-
#error ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#mime_type ⇒ String
An IANA published media type (MIME type).
-
#pages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPage>
Visual page layout for the Document.
-
#revisions ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevision>
Placeholder.
-
#shard_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentShardInfo
For a large document, sharding may be performed to produce several document shards.
-
#text ⇒ String
Optional.
-
#text_changes ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentTextChange>
Placeholder.
-
#text_styles ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentStyle>
Styles for the Document.text.
-
#uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Document
constructor
A new instance of GoogleCloudDocumentaiV1beta3Document.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Document
Returns a new instance of GoogleCloudDocumentaiV1beta3Document.
4357 4358 4359 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_assets ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentBlobAsset>
Optional. The blob assets in this document. This is used to store the content
of the inline blobs in this document, for example, image bytes, such that it
can be referenced by other fields in the document via asset id.
Corresponds to the JSON property blobAssets
4242 4243 4244 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4242 def blob_assets @blob_assets end |
#chunked_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocument
Represents the chunks that the document is divided into.
Corresponds to the JSON property chunkedDocument
4247 4248 4249 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4247 def chunked_document @chunked_document end |
#content ⇒ String
Optional. Inline document content, represented as a stream of bytes. Note: As
with all bytes fields, protobuffers use a pure binary representation,
whereas JSON representations use base64.
Corresponds to the JSON property content
NOTE: Values are automatically base64 encoded/decoded in the client library.
4255 4256 4257 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4255 def content @content end |
#docid ⇒ String
Optional. An internal identifier for document. Should be loggable (no PII).
Corresponds to the JSON property docid
4260 4261 4262 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4260 def docid @docid end |
#document_layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayout
Represents the parsed layout of a document as a collection of blocks that the
document is divided into.
Corresponds to the JSON property documentLayout
4266 4267 4268 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4266 def document_layout @document_layout end |
#entities ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntity>
A list of entities detected on Document.text. For document shards, entities in
this list may cross shard boundaries.
Corresponds to the JSON property entities
4272 4273 4274 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4272 def entities @entities end |
#entities_revision_id ⇒ String
The entity revision ID that document.entities field is based on. If this
field is set and entities_revisions is not empty, the entities in document.
entities field are the entities in the entity revision with this id and
document.entity_validation_output field is the entity_validation_output
field in this entity revision.
Corresponds to the JSON property entitiesRevisionId
4281 4282 4283 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4281 def entities_revision_id @entities_revision_id end |
#entities_revisions ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntitiesRevision>
A list of entity revisions. The entity revisions are appended to the document
in the processing order. This field can be used for comparing the entity
extraction results at different stages of the processing.
Corresponds to the JSON property entitiesRevisions
4288 4289 4290 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4288 def entities_revisions @entities_revisions end |
#entity_relations ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityRelation>
Placeholder. Relationship among Document.entities.
Corresponds to the JSON property entityRelations
4293 4294 4295 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4293 def entity_relations @entity_relations end |
#entity_validation_output ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutput
The output of the validation given the document and the validation rules.
Corresponds to the JSON property entityValidationOutput
4298 4299 4300 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4298 def entity_validation_output @entity_validation_output end |
#error ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4308 4309 4310 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4308 def error @error end |
#mime_type ⇒ String
An IANA published media type (MIME type).
Corresponds to the JSON property mimeType
4314 4315 4316 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4314 def mime_type @mime_type end |
#pages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPage>
Visual page layout for the Document.
Corresponds to the JSON property pages
4319 4320 4321 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4319 def pages @pages end |
#revisions ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevision>
Placeholder. Revision history of this document.
Corresponds to the JSON property revisions
4324 4325 4326 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4324 def revisions @revisions end |
#shard_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentShardInfo
For a large document, sharding may be performed to produce several document
shards. Each document shard contains this field to detail which shard it is.
Corresponds to the JSON property shardInfo
4330 4331 4332 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4330 def shard_info @shard_info end |
#text ⇒ String
Optional. UTF-8 encoded text in reading order from the document.
Corresponds to the JSON property text
4335 4336 4337 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4335 def text @text end |
#text_changes ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentTextChange>
Placeholder. A list of text corrections made to Document.text. This is usually
used for annotating corrections to OCR mistakes. Text changes for a given
revision may not overlap with each other.
Corresponds to the JSON property textChanges
4342 4343 4344 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4342 def text_changes @text_changes end |
#text_styles ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentStyle>
Styles for the Document.text.
Corresponds to the JSON property textStyles
4347 4348 4349 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4347 def text_styles @text_styles end |
#uri ⇒ String
Optional. Currently supports Google Cloud Storage URI of the form gs://
bucket_name/object_name. Object versioning is not supported. For more
information, refer to Google Cloud Storage Request URIs.
Corresponds to the JSON property uri
4355 4356 4357 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4355 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4362 def update!(**args) @blob_assets = args[:blob_assets] if args.key?(:blob_assets) @chunked_document = args[:chunked_document] if args.key?(:chunked_document) @content = args[:content] if args.key?(:content) @docid = args[:docid] if args.key?(:docid) @document_layout = args[:document_layout] if args.key?(:document_layout) @entities = args[:entities] if args.key?(:entities) @entities_revision_id = args[:entities_revision_id] if args.key?(:entities_revision_id) @entities_revisions = args[:entities_revisions] if args.key?(:entities_revisions) @entity_relations = args[:entity_relations] if args.key?(:entity_relations) @entity_validation_output = args[:entity_validation_output] if args.key?(:entity_validation_output) @error = args[:error] if args.key?(:error) @mime_type = args[:mime_type] if args.key?(:mime_type) @pages = args[:pages] if args.key?(:pages) @revisions = args[:revisions] if args.key?(:revisions) @shard_info = args[:shard_info] if args.key?(:shard_info) @text = args[:text] if args.key?(:text) @text_changes = args[:text_changes] if args.key?(:text_changes) @text_styles = args[:text_styles] if args.key?(:text_styles) @uri = args[:uri] if args.key?(:uri) end |