Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkTableChunkField
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkTableChunkField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The table chunk field in the chunk.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkTableChunkField
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkTableChunkField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkTableChunkField
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkTableChunkField.
4682 4683 4684 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4682 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
Corresponds to the JSON property annotations
4680 4681 4682 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4680 def annotations @annotations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4687 4688 4689 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4687 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) end |