Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Represents the parsed layout of a document as a collection of blocks that the document is divided into.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayout

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayout.



4683
4684
4685
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocksArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock>

List of blocks in the document. Corresponds to the JSON property blocks



4681
4682
4683
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4681

def blocks
  @blocks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4688
4689
4690
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4688

def update!(**args)
  @blocks = args[:blocks] if args.key?(:blocks)
end