Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Represents an image type block.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock.



4806
4807
4808
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations

Represents the annotation of a block or a chunk. Corresponds to the JSON property annotations



4775
4776
4777
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4775

def annotations
  @annotations
end

#blob_asset_idString

Optional. Asset id of the inline image. If set, find the image content in the blob_assets field. Corresponds to the JSON property blobAssetId

Returns:

  • (String)


4781
4782
4783
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4781

def blob_asset_id
  @blob_asset_id
end

#data_uriString

Optional. Data uri of the image. It is composed of four parts: a prefix (data:) , a MIME type indicating the type of data, an optional base64 token if non- textual, and the data itself: data:, Corresponds to the JSON property dataUri

Returns:

  • (String)


4788
4789
4790
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4788

def data_uri
  @data_uri
end

#gcs_uriString

Optional. Google Cloud Storage uri of the image. Corresponds to the JSON property gcsUri

Returns:

  • (String)


4793
4794
4795
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4793

def gcs_uri
  @gcs_uri
end

#image_textString

Text extracted from the image using OCR or alt text describing the image. Corresponds to the JSON property imageText

Returns:

  • (String)


4798
4799
4800
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4798

def image_text
  @image_text
end

#mime_typeString

Mime type of the image. An IANA published media type (MIME type). Corresponds to the JSON property mimeType

Returns:

  • (String)


4804
4805
4806
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4804

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4811
4812
4813
4814
4815
4816
4817
4818
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4811

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @blob_asset_id = args[:blob_asset_id] if args.key?(:blob_asset_id)
  @data_uri = args[:data_uri] if args.key?(:data_uri)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @image_text = args[:image_text] if args.key?(:image_text)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end