Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Represents a table type block.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
-
#body_rows ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow>
Body rows containing main table content.
-
#caption ⇒ String
Table caption/title.
-
#header_rows ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow>
Header rows at the top of the table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock.
4916 4917 4918 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
Corresponds to the JSON property annotations
4899 4900 4901 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4899 def annotations @annotations end |
#body_rows ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow>
Body rows containing main table content.
Corresponds to the JSON property bodyRows
4904 4905 4906 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4904 def body_rows @body_rows end |
#caption ⇒ String
Table caption/title.
Corresponds to the JSON property caption
4909 4910 4911 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4909 def caption @caption end |
#header_rows ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableRow>
Header rows at the top of the table.
Corresponds to the JSON property headerRows
4914 4915 4916 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4914 def header_rows @header_rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4921 4922 4923 4924 4925 4926 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4921 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @body_rows = args[:body_rows] if args.key?(:body_rows) @caption = args[:caption] if args.key?(:caption) @header_rows = args[:header_rows] if args.key?(:header_rows) end |