Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Represents a text type block.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
-
#blocks ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock>
A text block could further have child blocks.
-
#text ⇒ String
Text content stored in the block.
-
#type ⇒ String
Type of the text in the block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock.
4988 4989 4990 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
Corresponds to the JSON property annotations
4968 4969 4970 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4968 def annotations @annotations end |
#blocks ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock>
A text block could further have child blocks. Repeated blocks support further
hierarchies and nested blocks.
Corresponds to the JSON property blocks
4974 4975 4976 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4974 def blocks @blocks end |
#text ⇒ String
Text content stored in the block.
Corresponds to the JSON property text
4979 4980 4981 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4979 def text @text end |
#type ⇒ String
Type of the text in the block. Available options are: paragraph, subtitle,
heading-1, heading-2, heading-3, heading-4, heading-5, header,
footer.
Corresponds to the JSON property type
4986 4987 4988 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4986 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4993 4994 4995 4996 4997 4998 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4993 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @blocks = args[:blocks] if args.key?(:blocks) @text = args[:text] if args.key?(:text) @type = args[:type] if args.key?(:type) end |