Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

An entity that could be a phrase in the text or a property that belongs to the document. It is a known entity type, such as a person, an organization, or location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentEntity

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentEntity.



5130
5131
5132
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Optional. Confidence of detected Schema entity. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


5067
5068
5069
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5067

def confidence
  @confidence
end

#idString

Optional. Canonical id. This will be a unique value in the entity list for this document. Corresponds to the JSON property id

Returns:

  • (String)


5073
5074
5075
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5073

def id
  @id
end

#mention_idString

Optional. Deprecated. Use id field instead. Corresponds to the JSON property mentionId

Returns:

  • (String)


5078
5079
5080
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5078

def mention_id
  @mention_id
end

#mention_textString

Optional. Text value of the entity e.g. 1600 Amphitheatre Pkwy. Corresponds to the JSON property mentionText

Returns:

  • (String)


5083
5084
5085
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5083

def mention_text
  @mention_text
end

#method_propString

Optional. Specifies how the entity's value is obtained. Corresponds to the JSON property method

Returns:

  • (String)


5088
5089
5090
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5088

def method_prop
  @method_prop
end

#normalized_valueGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityNormalizedValue

Parsed and normalized entity value. Corresponds to the JSON property normalizedValue



5093
5094
5095
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5093

def normalized_value
  @normalized_value
end

#page_anchorGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageAnchor

Referencing the visual context of the entity in the Document.pages. Page anchors can be cross-page, consist of multiple bounding polygons and optionally reference specific layout element types. Corresponds to the JSON property pageAnchor



5100
5101
5102
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5100

def page_anchor
  @page_anchor
end

#propertiesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntity>

Optional. Entities can be nested to form a hierarchical data structure representing the content in the document. Corresponds to the JSON property properties



5106
5107
5108
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5106

def properties
  @properties
end

#provenanceGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5112
5113
5114
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5112

def provenance
  @provenance
end

#redactedBoolean Also known as: redacted?

Optional. Whether the entity will be redacted for de-identification purposes. Corresponds to the JSON property redacted

Returns:

  • (Boolean)


5117
5118
5119
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5117

def redacted
  @redacted
end

#text_anchorGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentTextAnchor

Text reference indexing into the Document.text. Corresponds to the JSON property textAnchor



5123
5124
5125
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5123

def text_anchor
  @text_anchor
end

#typeString

Required. Entity type from a schema e.g. Address. Corresponds to the JSON property type

Returns:

  • (String)


5128
5129
5130
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5128

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5135
5136
5137
5138
5139
5140
5141
5142
5143
5144
5145
5146
5147
5148
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5135

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @id = args[:id] if args.key?(:id)
  @mention_id = args[:mention_id] if args.key?(:mention_id)
  @mention_text = args[:mention_text] if args.key?(:mention_text)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @normalized_value = args[:normalized_value] if args.key?(:normalized_value)
  @page_anchor = args[:page_anchor] if args.key?(:page_anchor)
  @properties = args[:properties] if args.key?(:properties)
  @provenance = args[:provenance] if args.key?(:provenance)
  @redacted = args[:redacted] if args.key?(:redacted)
  @text_anchor = args[:text_anchor] if args.key?(:text_anchor)
  @type = args[:type] if args.key?(:type)
end