Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityNormalizedValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Parsed and normalized entity value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentEntityNormalizedValue

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentEntityNormalizedValue.



5240
5241
5242
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#address_valueGoogle::Apis::DocumentaiV1beta3::GoogleTypePostalAddress

Represents a postal address, such as for postal delivery or payments addresses. With a postal address, a postal service can deliver items to a premise, P.O. box, or similar. A postal address is not intended to model geographical locations like roads, towns, or mountains. In typical usage, an address would be created by user input or from importing existing data, depending on the type of process. Advice on address input or editing: - Use an internationalization-ready address widget such as https://github.com/google/ libaddressinput. - Users should not be presented with UI elements for input or editing of fields outside countries where that field is used. For more guidance on how to use this schema, see: https://support.google.com/business/ answer/6397478. Corresponds to the JSON property addressValue



5168
5169
5170
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5168

def address_value
  @address_value
end

#boolean_valueBoolean Also known as: boolean_value?

Boolean value. Can be used for entities with binary values, or for checkboxes. Corresponds to the JSON property booleanValue

Returns:

  • (Boolean)


5173
5174
5175
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5173

def boolean_value
  @boolean_value
end

#date_valueGoogle::Apis::DocumentaiV1beta3::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property dateValue



5186
5187
5188
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5186

def date_value
  @date_value
end

#datetime_valueGoogle::Apis::DocumentaiV1beta3::GoogleTypeDateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property datetimeValue



5204
5205
5206
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5204

def datetime_value
  @datetime_value
end

#float_valueFloat

Float value. Corresponds to the JSON property floatValue

Returns:

  • (Float)


5209
5210
5211
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5209

def float_value
  @float_value
end

#integer_valueFixnum

Integer value. Corresponds to the JSON property integerValue

Returns:

  • (Fixnum)


5214
5215
5216
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5214

def integer_value
  @integer_value
end

#money_valueGoogle::Apis::DocumentaiV1beta3::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property moneyValue



5219
5220
5221
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5219

def money_value
  @money_value
end

#signature_valueBoolean Also known as: signature_value?

A signature - a graphical representation of a person's name, often used to sign a document. Corresponds to the JSON property signatureValue

Returns:

  • (Boolean)


5225
5226
5227
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5225

def signature_value
  @signature_value
end

#textString

Optional. An optional field to store a normalized string. For some entity types, one of respective structured_value fields may also be populated. Also not all the types of structured_value will be normalized. For example, some processors may not generate float or integer normalized text by default. Below are sample formats mapped to structured values. - Money/Currency type ( money_value) is in the ISO 4217 text format. - Date type (date_value) is in the ISO 8601 text format. - Datetime type (datetime_value) is in the ISO 8601 text format. Corresponds to the JSON property text

Returns:

  • (String)


5238
5239
5240
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5238

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
5255
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5245

def update!(**args)
  @address_value = args[:address_value] if args.key?(:address_value)
  @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
  @date_value = args[:date_value] if args.key?(:date_value)
  @datetime_value = args[:datetime_value] if args.key?(:datetime_value)
  @float_value = args[:float_value] if args.key?(:float_value)
  @integer_value = args[:integer_value] if args.key?(:integer_value)
  @money_value = args[:money_value] if args.key?(:money_value)
  @signature_value = args[:signature_value] if args.key?(:signature_value)
  @text = args[:text] if args.key?(:text)
end