Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Validation result for a single validation rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult.



5327
5328
5329
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ruleString

Optional. The name of the rule resource that is used for validation. Format: projects/project/locations/location/rules/rule` Corresponds to the JSON propertyrule`

Returns:

  • (String)


5304
5305
5306
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5304

def rule
  @rule
end

#rule_descriptionString

The description of the validation rule. Corresponds to the JSON property ruleDescription

Returns:

  • (String)


5309
5310
5311
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5309

def rule_description
  @rule_description
end

#rule_nameString

The display name of the validation rule. Corresponds to the JSON property ruleName

Returns:

  • (String)


5314
5315
5316
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5314

def rule_name
  @rule_name
end

#validation_detailsString

The detailed information of the running the validation process using the entity from the document based on the validation rule. Corresponds to the JSON property validationDetails

Returns:

  • (String)


5320
5321
5322
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5320

def validation_details
  @validation_details
end

#validation_result_typeString

The result of the validation rule. Corresponds to the JSON property validationResultType

Returns:

  • (String)


5325
5326
5327
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5325

def validation_result_type
  @validation_result_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5332
5333
5334
5335
5336
5337
5338
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5332

def update!(**args)
  @rule = args[:rule] if args.key?(:rule)
  @rule_description = args[:rule_description] if args.key?(:rule_description)
  @rule_name = args[:rule_name] if args.key?(:rule_name)
  @validation_details = args[:validation_details] if args.key?(:validation_details)
  @validation_result_type = args[:validation_result_type] if args.key?(:validation_result_type)
end