Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Metadata about a document.
Instance Attribute Summary collapse
-
#dataset_type ⇒ String
Type of the dataset split to which the document belongs.
-
#display_name ⇒ String
The display name of the document.
-
#document_id ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentId
Document Identifier.
-
#labeling_state ⇒ String
Labeling state of the document.
-
#page_count ⇒ Fixnum
Number of pages in the document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentMetadata
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentMetadata
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentMetadata.
5468 5469 5470 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_type ⇒ String
Type of the dataset split to which the document belongs.
Corresponds to the JSON property datasetType
5446 5447 5448 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5446 def dataset_type @dataset_type end |
#display_name ⇒ String
The display name of the document.
Corresponds to the JSON property displayName
5451 5452 5453 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5451 def display_name @display_name end |
#document_id ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentId
Document Identifier.
Corresponds to the JSON property documentId
5456 5457 5458 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5456 def document_id @document_id end |
#labeling_state ⇒ String
Labeling state of the document.
Corresponds to the JSON property labelingState
5461 5462 5463 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5461 def labeling_state @labeling_state end |
#page_count ⇒ Fixnum
Number of pages in the document.
Corresponds to the JSON property pageCount
5466 5467 5468 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5466 def page_count @page_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5473 5474 5475 5476 5477 5478 5479 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5473 def update!(**args) @dataset_type = args[:dataset_type] if args.key?(:dataset_type) @display_name = args[:display_name] if args.key?(:display_name) @document_id = args[:document_id] if args.key?(:document_id) @labeling_state = args[:labeling_state] if args.key?(:labeling_state) @page_count = args[:page_count] if args.key?(:page_count) end |