Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPage
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
A page in a Document.
Instance Attribute Summary collapse
-
#blocks ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageBlock>
A list of visually detected text blocks on the page.
-
#detected_barcodes ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode>
A list of detected barcodes.
-
#detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
-
#dimension ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDimension
Dimension for the page.
-
#form_fields ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageFormField>
A list of visually detected form fields on the page.
-
#image ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageImage
Rendered image contents for this page.
-
#image_quality_scores ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageImageQualityScores
Image quality scores for the page image.
-
#layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
-
#lines ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLine>
A list of visually detected text lines on the page.
-
#page_number ⇒ Fixnum
1-based index for current Page in a parent Document.
-
#paragraphs ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageParagraph>
A list of visually detected text paragraphs on the page.
-
#provenance ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
-
#symbols ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageSymbol>
A list of visually detected symbols on the page.
-
#tables ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTable>
A list of visually detected tables on the page.
-
#tokens ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageToken>
A list of visually detected tokens on the page.
-
#transforms ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageMatrix>
Transformation matrices that were applied to the original document image to produce Page.image.
-
#visual_elements ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageVisualElement>
A list of detected non-text visual elements, for example, checkbox, signature etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPage
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentPage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPage
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPage.
5638 5639 5640 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocks ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageBlock>
A list of visually detected text blocks on the page. A block has a set of
lines (collected into paragraphs) that have a common line-spacing and
orientation.
Corresponds to the JSON property blocks
5550 5551 5552 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5550 def blocks @blocks end |
#detected_barcodes ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode>
A list of detected barcodes.
Corresponds to the JSON property detectedBarcodes
5555 5556 5557 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5555 def @detected_barcodes end |
#detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
Corresponds to the JSON property detectedLanguages
5560 5561 5562 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5560 def detected_languages @detected_languages end |
#dimension ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDimension
Dimension for the page.
Corresponds to the JSON property dimension
5565 5566 5567 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5565 def dimension @dimension end |
#form_fields ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageFormField>
A list of visually detected form fields on the page.
Corresponds to the JSON property formFields
5570 5571 5572 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5570 def form_fields @form_fields end |
#image ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageImage
Rendered image contents for this page.
Corresponds to the JSON property image
5575 5576 5577 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5575 def image @image end |
#image_quality_scores ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageImageQualityScores
Image quality scores for the page image.
Corresponds to the JSON property imageQualityScores
5580 5581 5582 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5580 def image_quality_scores @image_quality_scores end |
#layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
5585 5586 5587 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5585 def layout @layout end |
#lines ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLine>
A list of visually detected text lines on the page. A collection of tokens
that a human would perceive as a line.
Corresponds to the JSON property lines
5591 5592 5593 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5591 def lines @lines end |
#page_number ⇒ Fixnum
1-based index for current Page in a parent Document. Useful when a page is
taken out of a Document for individual processing.
Corresponds to the JSON property pageNumber
5597 5598 5599 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5597 def page_number @page_number end |
#paragraphs ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageParagraph>
A list of visually detected text paragraphs on the page. A collection of lines
that a human would perceive as a paragraph.
Corresponds to the JSON property paragraphs
5603 5604 5605 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5603 def paragraphs @paragraphs end |
#provenance ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
5609 5610 5611 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5609 def provenance @provenance end |
#symbols ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageSymbol>
A list of visually detected symbols on the page.
Corresponds to the JSON property symbols
5614 5615 5616 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5614 def symbols @symbols end |
#tables ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTable>
A list of visually detected tables on the page.
Corresponds to the JSON property tables
5619 5620 5621 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5619 def tables @tables end |
#tokens ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageToken>
A list of visually detected tokens on the page.
Corresponds to the JSON property tokens
5624 5625 5626 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5624 def tokens @tokens end |
#transforms ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageMatrix>
Transformation matrices that were applied to the original document image to
produce Page.image.
Corresponds to the JSON property transforms
5630 5631 5632 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5630 def transforms @transforms end |
#visual_elements ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageVisualElement>
A list of detected non-text visual elements, for example, checkbox, signature
etc. on the page.
Corresponds to the JSON property visualElements
5636 5637 5638 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5636 def visual_elements @visual_elements end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 5658 5659 5660 5661 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5643 def update!(**args) @blocks = args[:blocks] if args.key?(:blocks) @detected_barcodes = args[:detected_barcodes] if args.key?(:detected_barcodes) @detected_languages = args[:detected_languages] if args.key?(:detected_languages) @dimension = args[:dimension] if args.key?(:dimension) @form_fields = args[:form_fields] if args.key?(:form_fields) @image = args[:image] if args.key?(:image) @image_quality_scores = args[:image_quality_scores] if args.key?(:image_quality_scores) @layout = args[:layout] if args.key?(:layout) @lines = args[:lines] if args.key?(:lines) @page_number = args[:page_number] if args.key?(:page_number) @paragraphs = args[:paragraphs] if args.key?(:paragraphs) @provenance = args[:provenance] if args.key?(:provenance) @symbols = args[:symbols] if args.key?(:symbols) @tables = args[:tables] if args.key?(:tables) @tokens = args[:tokens] if args.key?(:tokens) @transforms = args[:transforms] if args.key?(:transforms) @visual_elements = args[:visual_elements] if args.key?(:visual_elements) end |