Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Represents a weak reference to a page element within a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef.



5717
5718
5719
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5717

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_polyGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property boundingPoly



5692
5693
5694
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5692

def bounding_poly
  @bounding_poly
end

#confidenceFloat

Optional. Confidence of detected page element, if applicable. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


5697
5698
5699
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5697

def confidence
  @confidence
end

#layout_idString

Optional. Deprecated. Use PageRef.bounding_poly instead. Corresponds to the JSON property layoutId

Returns:

  • (String)


5702
5703
5704
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5702

def layout_id
  @layout_id
end

#layout_typeString

Optional. The type of the layout element that is being referenced if any. Corresponds to the JSON property layoutType

Returns:

  • (String)


5707
5708
5709
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5707

def layout_type
  @layout_type
end

#pageFixnum

Required. Index into the Document.pages element, for example using Document. pages to locate the related page element. This field is skipped when its value is the default 0. See https://developers.google.com/protocol-buffers/ docs/proto3#json. Corresponds to the JSON property page

Returns:

  • (Fixnum)


5715
5716
5717
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5715

def page
  @page
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5722
5723
5724
5725
5726
5727
5728
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5722

def update!(**args)
  @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
  @confidence = args[:confidence] if args.key?(:confidence)
  @layout_id = args[:layout_id] if args.key?(:layout_id)
  @layout_type = args[:layout_type] if args.key?(:layout_type)
  @page = args[:page] if args.key?(:page)
end