Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageBlock

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

A block has a set of lines (collected into paragraphs) that have a common line- spacing and orientation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageBlock

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageBlock.



5771
5772
5773
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_languagesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5758
5759
5760
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5758

def detected_languages
  @detected_languages
end

#layoutGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5763
5764
5765
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5763

def layout
  @layout
end

#provenanceGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5769
5770
5771
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5769

def provenance
  @provenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5776
5777
5778
5779
5780
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5776

def update!(**args)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
end