Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
A detected barcode.
Instance Attribute Summary collapse
-
#barcode ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Barcode
Encodes the detailed information of a barcode.
-
#layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode.
5797 5798 5799 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5797 def initialize(**args) update!(**args) end |
Instance Attribute Details
#barcode ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Barcode
Encodes the detailed information of a barcode.
Corresponds to the JSON property barcode
5790 5791 5792 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5790 def @barcode end |
#layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
5795 5796 5797 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5795 def layout @layout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5802 5803 5804 5805 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5802 def update!(**args) @barcode = args[:barcode] if args.key?(:barcode) @layout = args[:layout] if args.key?(:layout) end |