Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageFormField
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageFormField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
A form field detected on the page.
Instance Attribute Summary collapse
-
#corrected_key_text ⇒ String
Created for Labeling UI to export key text.
-
#corrected_value_text ⇒ String
Created for Labeling UI to export value text.
-
#field_name ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
-
#field_value ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
-
#name_detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages for name together with confidence.
-
#provenance ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
-
#value_detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages for value together with confidence.
-
#value_type ⇒ String
If the value is non-textual, this field represents the type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageFormField
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentPageFormField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageFormField
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageFormField.
5916 5917 5918 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corrected_key_text ⇒ String
Created for Labeling UI to export key text. If corrections were made to the
text identified by the field_name.text_anchor, this field will contain the
correction.
Corresponds to the JSON property correctedKeyText
5874 5875 5876 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5874 def corrected_key_text @corrected_key_text end |
#corrected_value_text ⇒ String
Created for Labeling UI to export value text. If corrections were made to the
text identified by the field_value.text_anchor, this field will contain the
correction.
Corresponds to the JSON property correctedValueText
5881 5882 5883 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5881 def corrected_value_text @corrected_value_text end |
#field_name ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property fieldName
5886 5887 5888 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5886 def field_name @field_name end |
#field_value ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property fieldValue
5891 5892 5893 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5891 def field_value @field_value end |
#name_detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages for name together with confidence.
Corresponds to the JSON property nameDetectedLanguages
5896 5897 5898 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5896 def name_detected_languages @name_detected_languages end |
#provenance ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
5902 5903 5904 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5902 def provenance @provenance end |
#value_detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages for value together with confidence.
Corresponds to the JSON property valueDetectedLanguages
5907 5908 5909 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5907 def value_detected_languages @value_detected_languages end |
#value_type ⇒ String
If the value is non-textual, this field represents the type. Current valid
values are: - blank (this indicates the field_value is normal text) -
unfilled_checkbox - filled_checkbox
Corresponds to the JSON property valueType
5914 5915 5916 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5914 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5921 def update!(**args) @corrected_key_text = args[:corrected_key_text] if args.key?(:corrected_key_text) @corrected_value_text = args[:corrected_value_text] if args.key?(:corrected_value_text) @field_name = args[:field_name] if args.key?(:field_name) @field_value = args[:field_value] if args.key?(:field_value) @name_detected_languages = args[:name_detected_languages] if args.key?(:name_detected_languages) @provenance = args[:provenance] if args.key?(:provenance) @value_detected_languages = args[:value_detected_languages] if args.key?(:value_detected_languages) @value_type = args[:value_type] if args.key?(:value_type) end |