Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Visual element describing a layout unit on a page.
Instance Attribute Summary collapse
-
#bounding_poly ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BoundingPoly
A bounding polygon for the detected image annotation.
-
#confidence ⇒ Float
Confidence of the current Layout within context of the object this layout is for.
-
#orientation ⇒ String
Detected orientation for the Layout.
-
#text_anchor ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentTextAnchor
Text reference indexing into the Document.text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageLayout
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentPageLayout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageLayout
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageLayout.
6052 6053 6054 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_poly ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingPoly
6033 6034 6035 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6033 def bounding_poly @bounding_poly end |
#confidence ⇒ Float
Confidence of the current Layout within context of the object this layout is
for. e.g. confidence can be for a single token, a table, a visual element, etc.
depending on context. Range [0, 1].
Corresponds to the JSON property confidence
6040 6041 6042 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6040 def confidence @confidence end |
#orientation ⇒ String
Detected orientation for the Layout.
Corresponds to the JSON property orientation
6045 6046 6047 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6045 def orientation @orientation end |
#text_anchor ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentTextAnchor
Text reference indexing into the Document.text.
Corresponds to the JSON property textAnchor
6050 6051 6052 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6050 def text_anchor @text_anchor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6057 6058 6059 6060 6061 6062 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6057 def update!(**args) @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly) @confidence = args[:confidence] if args.key?(:confidence) @orientation = args[:orientation] if args.key?(:orientation) @text_anchor = args[:text_anchor] if args.key?(:text_anchor) end |