Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

A table representation similar to HTML table structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageTable

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageTable.



6208
6209
6210
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#body_rowsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTableTableRow>

Body rows of the table. Corresponds to the JSON property bodyRows



6185
6186
6187
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6185

def body_rows
  @body_rows
end

#detected_languagesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



6190
6191
6192
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6190

def detected_languages
  @detected_languages
end

#header_rowsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTableTableRow>

Header rows of the table. Corresponds to the JSON property headerRows



6195
6196
6197
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6195

def header_rows
  @header_rows
end

#layoutGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



6200
6201
6202
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6200

def layout
  @layout
end

#provenanceGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



6206
6207
6208
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6206

def provenance
  @provenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6213
6214
6215
6216
6217
6218
6219
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6213

def update!(**args)
  @body_rows = args[:body_rows] if args.key?(:body_rows)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
end