Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageVisualElement
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageVisualElement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Detected non-text visual elements, for example, checkbox, signature etc. on the page.
Instance Attribute Summary collapse
-
#detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
-
#layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
-
#type ⇒ String
Type of the VisualElement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageVisualElement
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentPageVisualElement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageVisualElement
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageVisualElement.
6561 6562 6563 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6561 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detected_languages ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
Corresponds to the JSON property detectedLanguages
6549 6550 6551 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6549 def detected_languages @detected_languages end |
#layout ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
6554 6555 6556 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6554 def layout @layout end |
#type ⇒ String
Type of the VisualElement.
Corresponds to the JSON property type
6559 6560 6561 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6559 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6566 6567 6568 6569 6570 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6566 def update!(**args) @detected_languages = args[:detected_languages] if args.key?(:detected_languages) @layout = args[:layout] if args.key?(:layout) @type = args[:type] if args.key?(:type) end |