Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevision
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Contains past or forward revisions of this document.
Instance Attribute Summary collapse
-
#agent ⇒ String
If the change was made by a person specify the name or id of that person.
-
#create_time ⇒ String
The time that the revision was created, internally generated by doc proto storage at the time of create.
-
#human_review ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevisionHumanReview
Human Review information of the document.
-
#id ⇒ String
Id of the revision, internally generated by doc proto storage.
-
#parent ⇒ Array<Fixnum>
The revisions that this revision is based on.
-
#parent_ids ⇒ Array<String>
The revisions that this revision is based on.
-
#processor ⇒ String
If the annotation was made by processor identify the processor by its resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentRevision
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentRevision
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentRevision.
6690 6691 6692 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
If the change was made by a person specify the name or id of that person.
Corresponds to the JSON property agent
6651 6652 6653 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6651 def agent @agent end |
#create_time ⇒ String
The time that the revision was created, internally generated by doc proto
storage at the time of create.
Corresponds to the JSON property createTime
6657 6658 6659 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6657 def create_time @create_time end |
#human_review ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevisionHumanReview
Human Review information of the document.
Corresponds to the JSON property humanReview
6662 6663 6664 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6662 def human_review @human_review end |
#id ⇒ String
Id of the revision, internally generated by doc proto storage. Unique within
the context of the document.
Corresponds to the JSON property id
6668 6669 6670 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6668 def id @id end |
#parent ⇒ Array<Fixnum>
The revisions that this revision is based on. This can include one or more
parent (when documents are merged.) This field represents the index into the
revisions field.
Corresponds to the JSON property parent
6675 6676 6677 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6675 def parent @parent end |
#parent_ids ⇒ Array<String>
The revisions that this revision is based on. Must include all the ids that
have anything to do with this revision - eg. there are provenance.parent.
revision fields that index into this field.
Corresponds to the JSON property parentIds
6682 6683 6684 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6682 def parent_ids @parent_ids end |
#processor ⇒ String
If the annotation was made by processor identify the processor by its resource
name.
Corresponds to the JSON property processor
6688 6689 6690 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6688 def processor @processor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6695 6696 6697 6698 6699 6700 6701 6702 6703 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6695 def update!(**args) @agent = args[:agent] if args.key?(:agent) @create_time = args[:create_time] if args.key?(:create_time) @human_review = args[:human_review] if args.key?(:human_review) @id = args[:id] if args.key?(:id) @parent = args[:parent] if args.key?(:parent) @parent_ids = args[:parent_ids] if args.key?(:parent_ids) @processor = args[:processor] if args.key?(:processor) end |