Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevisionHumanReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Human Review information of the document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentRevisionHumanReview

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentRevisionHumanReview.



6739
6740
6741
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Human review state. e.g. requested, succeeded, rejected. Corresponds to the JSON property state

Returns:

  • (String)


6731
6732
6733
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6731

def state
  @state
end

#state_messageString

A message providing more details about the current state of processing. For example, the rejection reason when the state is rejected. Corresponds to the JSON property stateMessage

Returns:

  • (String)


6737
6738
6739
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6737

def state_message
  @state_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6744
6745
6746
6747
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6744

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
end