Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentShardInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentShardInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentShardInfo.



6992
6993
6994
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_offsetFixnum

The index of the first page in Document.pages in the overall document global pages. Available for document shards created by the document splitter. Corresponds to the JSON property pageOffset

Returns:

  • (Fixnum)


6974
6975
6976
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6974

def page_offset
  @page_offset
end

#shard_countFixnum

Total number of shards. Corresponds to the JSON property shardCount

Returns:

  • (Fixnum)


6979
6980
6981
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6979

def shard_count
  @shard_count
end

#shard_indexFixnum

The 0-based index of this shard. Corresponds to the JSON property shardIndex

Returns:

  • (Fixnum)


6984
6985
6986
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6984

def shard_index
  @shard_index
end

#text_offsetFixnum

The index of the first character in Document.text in the overall document global text. Corresponds to the JSON property textOffset

Returns:

  • (Fixnum)


6990
6991
6992
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6990

def text_offset
  @text_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6997
6998
6999
7000
7001
7002
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6997

def update!(**args)
  @page_offset = args[:page_offset] if args.key?(:page_offset)
  @shard_count = args[:shard_count] if args.key?(:shard_count)
  @shard_index = args[:shard_index] if args.key?(:shard_index)
  @text_offset = args[:text_offset] if args.key?(:text_offset)
end