Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Evaluation
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Evaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
An evaluation of a ProcessorVersion's performance.
Instance Attribute Summary collapse
-
#all_entities_metrics ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics
Metrics across multiple confidence levels.
-
#create_time ⇒ String
The time that the evaluation was created.
-
#document_counters ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationCounters
Evaluation counters for the documents that were used.
-
#entity_metrics ⇒ Hash<String,Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics>
Metrics across confidence levels, for different entities.
-
#kms_key_name ⇒ String
The KMS key name used for encryption.
-
#kms_key_version_name ⇒ String
The KMS key version with which data is encrypted.
-
#name ⇒ String
The resource name of the evaluation.
-
#revisions ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationEvaluationRevision>
Contains all revisions of the evaluation, excluding the latest one.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Evaluation
constructor
A new instance of GoogleCloudDocumentaiV1beta3Evaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Evaluation
Returns a new instance of GoogleCloudDocumentaiV1beta3Evaluation.
7456 7457 7458 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_entities_metrics ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics
Metrics across multiple confidence levels.
Corresponds to the JSON property allEntitiesMetrics
7417 7418 7419 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7417 def all_entities_metrics @all_entities_metrics end |
#create_time ⇒ String
The time that the evaluation was created.
Corresponds to the JSON property createTime
7422 7423 7424 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7422 def create_time @create_time end |
#document_counters ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationCounters
Evaluation counters for the documents that were used.
Corresponds to the JSON property documentCounters
7427 7428 7429 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7427 def document_counters @document_counters end |
#entity_metrics ⇒ Hash<String,Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics>
Metrics across confidence levels, for different entities.
Corresponds to the JSON property entityMetrics
7432 7433 7434 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7432 def entity_metrics @entity_metrics end |
#kms_key_name ⇒ String
The KMS key name used for encryption.
Corresponds to the JSON property kmsKeyName
7437 7438 7439 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7437 def kms_key_name @kms_key_name end |
#kms_key_version_name ⇒ String
The KMS key version with which data is encrypted.
Corresponds to the JSON property kmsKeyVersionName
7442 7443 7444 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7442 def kms_key_version_name @kms_key_version_name end |
#name ⇒ String
The resource name of the evaluation. Format: projects/project/locations/
location/processors/processor/processorVersions/processor_version/
evaluations/evaluation`
Corresponds to the JSON propertyname`
7449 7450 7451 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7449 def name @name end |
#revisions ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationEvaluationRevision>
Contains all revisions of the evaluation, excluding the latest one.
Corresponds to the JSON property revisions
7454 7455 7456 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7454 def revisions @revisions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7461 def update!(**args) @all_entities_metrics = args[:all_entities_metrics] if args.key?(:all_entities_metrics) @create_time = args[:create_time] if args.key?(:create_time) @document_counters = args[:document_counters] if args.key?(:document_counters) @entity_metrics = args[:entity_metrics] if args.key?(:entity_metrics) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_version_name = args[:kms_key_version_name] if args.key?(:kms_key_version_name) @name = args[:name] if args.key?(:name) @revisions = args[:revisions] if args.key?(:revisions) end |