Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Evaluation metrics, either in aggregate or about a specific entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMetrics

Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationMetrics.



7633
7634
7635
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#f1_scoreFloat

The calculated F1 score. Corresponds to the JSON property f1Score

Returns:

  • (Float)


7581
7582
7583
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7581

def f1_score
  @f1_score
end

#false_negatives_countFixnum

The amount of false negatives. Corresponds to the JSON property falseNegativesCount

Returns:

  • (Fixnum)


7586
7587
7588
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7586

def false_negatives_count
  @false_negatives_count
end

#false_positives_countFixnum

The amount of false positives. Corresponds to the JSON property falsePositivesCount

Returns:

  • (Fixnum)


7591
7592
7593
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7591

def false_positives_count
  @false_positives_count
end

#ground_truth_document_countFixnum

The amount of documents with a ground truth occurrence. Corresponds to the JSON property groundTruthDocumentCount

Returns:

  • (Fixnum)


7596
7597
7598
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7596

def ground_truth_document_count
  @ground_truth_document_count
end

#ground_truth_occurrences_countFixnum

The amount of occurrences in ground truth documents. Corresponds to the JSON property groundTruthOccurrencesCount

Returns:

  • (Fixnum)


7601
7602
7603
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7601

def ground_truth_occurrences_count
  @ground_truth_occurrences_count
end

#precisionFloat

The calculated precision. Corresponds to the JSON property precision

Returns:

  • (Float)


7606
7607
7608
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7606

def precision
  @precision
end

#predicted_document_countFixnum

The amount of documents with a predicted occurrence. Corresponds to the JSON property predictedDocumentCount

Returns:

  • (Fixnum)


7611
7612
7613
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7611

def predicted_document_count
  @predicted_document_count
end

#predicted_occurrences_countFixnum

The amount of occurrences in predicted documents. Corresponds to the JSON property predictedOccurrencesCount

Returns:

  • (Fixnum)


7616
7617
7618
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7616

def predicted_occurrences_count
  @predicted_occurrences_count
end

#recallFloat

The calculated recall. Corresponds to the JSON property recall

Returns:

  • (Float)


7621
7622
7623
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7621

def recall
  @recall
end

#total_documents_countFixnum

The amount of documents that had an occurrence of this label. Corresponds to the JSON property totalDocumentsCount

Returns:

  • (Fixnum)


7626
7627
7628
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7626

def total_documents_count
  @total_documents_count
end

#true_positives_countFixnum

The amount of true positives. Corresponds to the JSON property truePositivesCount

Returns:

  • (Fixnum)


7631
7632
7633
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7631

def true_positives_count
  @true_positives_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
7648
7649
7650
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7638

def update!(**args)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count)
  @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count)
  @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count)
  @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count)
  @precision = args[:precision] if args.key?(:precision)
  @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count)
  @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count)
  @recall = args[:recall] if args.key?(:recall)
  @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count)
  @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count)
end