Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Metrics across multiple confidence levels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics

Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics.



7688
7689
7690
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auprcFloat

The calculated area under the precision recall curve (AUPRC), computed by integrating over all confidence thresholds. Corresponds to the JSON property auprc

Returns:

  • (Float)


7654
7655
7656
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7654

def auprc
  @auprc
end

#auprc_exactFloat

The AUPRC for metrics with fuzzy matching disabled, i.e., exact matching only. Corresponds to the JSON property auprcExact

Returns:

  • (Float)


7659
7660
7661
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7659

def auprc_exact
  @auprc_exact
end

#confidence_level_metricsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationConfidenceLevelMetrics>

Metrics across confidence levels with fuzzy matching enabled. Corresponds to the JSON property confidenceLevelMetrics



7664
7665
7666
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7664

def confidence_level_metrics
  @confidence_level_metrics
end

#confidence_level_metrics_exactArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationConfidenceLevelMetrics>

Metrics across confidence levels with only exact matching. Corresponds to the JSON property confidenceLevelMetricsExact



7669
7670
7671
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7669

def confidence_level_metrics_exact
  @confidence_level_metrics_exact
end

#estimated_calibration_errorFloat

The Estimated Calibration Error (ECE) of the confidence of the predicted entities. Corresponds to the JSON property estimatedCalibrationError

Returns:

  • (Float)


7675
7676
7677
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7675

def estimated_calibration_error
  @estimated_calibration_error
end

#estimated_calibration_error_exactFloat

The ECE for the predicted entities with fuzzy matching disabled, i.e., exact matching only. Corresponds to the JSON property estimatedCalibrationErrorExact

Returns:

  • (Float)


7681
7682
7683
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7681

def estimated_calibration_error_exact
  @estimated_calibration_error_exact
end

#metrics_typeString

The metrics type for the label. Corresponds to the JSON property metricsType

Returns:

  • (String)


7686
7687
7688
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7686

def metrics_type
  @metrics_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7693
7694
7695
7696
7697
7698
7699
7700
7701
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7693

def update!(**args)
  @auprc = args[:auprc] if args.key?(:auprc)
  @auprc_exact = args[:auprc_exact] if args.key?(:auprc_exact)
  @confidence_level_metrics = args[:confidence_level_metrics] if args.key?(:confidence_level_metrics)
  @confidence_level_metrics_exact = args[:confidence_level_metrics_exact] if args.key?(:confidence_level_metrics_exact)
  @estimated_calibration_error = args[:estimated_calibration_error] if args.key?(:estimated_calibration_error)
  @estimated_calibration_error_exact = args[:estimated_calibration_error_exact] if args.key?(:estimated_calibration_error_exact)
  @metrics_type = args[:metrics_type] if args.key?(:metrics_type)
end