Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GetDocumentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3GetDocumentResponse

Returns a new instance of GoogleCloudDocumentaiV1beta3GetDocumentResponse.



7956
7957
7958
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property document



7954
7955
7956
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7954

def document
  @document
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7961
7962
7963
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7961

def update!(**args)
  @document = args[:document] if args.key?(:document)
end