Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3HumanReviewStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3HumanReviewStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The status of human review on a processed document.
Instance Attribute Summary collapse
-
#human_review_operation ⇒ String
The name of the operation triggered by the processed document.
-
#state ⇒ String
The state of human review on the processing request.
-
#state_message ⇒ String
A message providing more details about the human review state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3HumanReviewStatus
constructor
A new instance of GoogleCloudDocumentaiV1beta3HumanReviewStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3HumanReviewStatus
Returns a new instance of GoogleCloudDocumentaiV1beta3HumanReviewStatus.
7948 7949 7950 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#human_review_operation ⇒ String
The name of the operation triggered by the processed document. This field is
populated only when the state is HUMAN_REVIEW_IN_PROGRESS. It has the same
response type and metadata as the long-running operation returned by
ReviewDocument.
Corresponds to the JSON property humanReviewOperation
7936 7937 7938 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7936 def human_review_operation @human_review_operation end |
#state ⇒ String
The state of human review on the processing request.
Corresponds to the JSON property state
7941 7942 7943 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7941 def state @state end |
#state_message ⇒ String
A message providing more details about the human review state.
Corresponds to the JSON property stateMessage
7946 7947 7948 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7946 def @state_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7953 7954 7955 7956 7957 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7953 def update!(**args) @human_review_operation = args[:human_review_operation] if args.key?(:human_review_operation) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) end |