Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Config for importing documents. Each batch can have its own dataset split type.
Instance Attribute Summary collapse
-
#auto_split_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfigAutoSplitConfig
The config for auto-split.
-
#batch_input_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchDocumentsInputConfig
The common config to specify a set of documents used as input.
-
#dataset_split ⇒ String
Target dataset split where the documents must be stored.
-
#document_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig
constructor
A new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig
Returns a new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig.
8145 8146 8147 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_split_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfigAutoSplitConfig
The config for auto-split.
Corresponds to the JSON property autoSplitConfig
8124 8125 8126 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8124 def auto_split_config @auto_split_config end |
#batch_input_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchDocumentsInputConfig
The common config to specify a set of documents used as input.
Corresponds to the JSON property batchInputConfig
8129 8130 8131 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8129 def batch_input_config @batch_input_config end |
#dataset_split ⇒ String
Target dataset split where the documents must be stored.
Corresponds to the JSON property datasetSplit
8134 8135 8136 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8134 def dataset_split @dataset_split end |
#document_type ⇒ String
Optional. If set, determines the type of the documents to be imported in this
batch. It can be used to auto-label the documents with a single entity of the
provided type. This field can only be used with a classifier or splitter
processor. Providing this field is mutually exclusive with entities and
auto_labeling_config.
Corresponds to the JSON property documentType
8143 8144 8145 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8143 def document_type @document_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8150 8151 8152 8153 8154 8155 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8150 def update!(**args) @auto_split_config = args[:auto_split_config] if args.key?(:auto_split_config) @batch_input_config = args[:batch_input_config] if args.key?(:batch_input_config) @dataset_split = args[:dataset_split] if args.key?(:dataset_split) @document_type = args[:document_type] if args.key?(:document_type) end |