Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3OcrConfigHints
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3OcrConfigHints
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Hints for OCR Engine
Instance Attribute Summary collapse
-
#language_hints ⇒ Array<String>
List of BCP-47 language codes to use for OCR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3OcrConfigHints
constructor
A new instance of GoogleCloudDocumentaiV1beta3OcrConfigHints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3OcrConfigHints
Returns a new instance of GoogleCloudDocumentaiV1beta3OcrConfigHints.
8660 8661 8662 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_hints ⇒ Array<String>
List of BCP-47 language codes to use for OCR. In most cases, not specifying it
yields the best results since it enables automatic language detection. For
languages based on the Latin alphabet, setting hints is not needed. In rare
cases, when the language of the text in the image is known, setting a hint
will help get better results (although it will be a significant hindrance if
the hint is wrong).
Corresponds to the JSON property languageHints
8658 8659 8660 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8658 def language_hints @language_hints end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8665 8666 8667 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8665 def update!(**args) @language_hints = args[:language_hints] if args.key?(:language_hints) end |