Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Serving config for chunking.
Instance Attribute Summary collapse
-
#breakpoint_percentile_threshold ⇒ Fixnum
Optional.
-
#chunk_size ⇒ Fixnum
Optional.
-
#include_ancestor_headings ⇒ Boolean
(also: #include_ancestor_headings?)
Optional.
-
#semantic_chunking_group_size ⇒ Boolean
(also: #semantic_chunking_group_size?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig.
8872 8873 8874 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#breakpoint_percentile_threshold ⇒ Fixnum
Optional. The percentile of cosine dissimilarity that must be exceeded between
a group of tokens and the next. The smaller this number is, the more chunks
will be generated. THIS FIELD IS NOT YET USED.
Corresponds to the JSON property breakpointPercentileThreshold
8852 8853 8854 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8852 def breakpoint_percentile_threshold @breakpoint_percentile_threshold end |
#chunk_size ⇒ Fixnum
Optional. The chunk sizes to use when splitting documents, in order of level.
Corresponds to the JSON property chunkSize
8857 8858 8859 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8857 def chunk_size @chunk_size end |
#include_ancestor_headings ⇒ Boolean Also known as: include_ancestor_headings?
Optional. Whether or not to include ancestor headings when splitting.
Corresponds to the JSON property includeAncestorHeadings
8862 8863 8864 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8862 def include_ancestor_headings @include_ancestor_headings end |
#semantic_chunking_group_size ⇒ Boolean Also known as: semantic_chunking_group_size?
Optional. The number of tokens to group together when evaluating semantic
similarity. THIS FIELD IS NOT YET USED.
Corresponds to the JSON property semanticChunkingGroupSize
8869 8870 8871 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8869 def semantic_chunking_group_size @semantic_chunking_group_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8877 8878 8879 8880 8881 8882 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8877 def update!(**args) @breakpoint_percentile_threshold = args[:breakpoint_percentile_threshold] if args.key?(:breakpoint_percentile_threshold) @chunk_size = args[:chunk_size] if args.key?(:chunk_size) @include_ancestor_headings = args[:include_ancestor_headings] if args.key?(:include_ancestor_headings) @semantic_chunking_group_size = args[:semantic_chunking_group_size] if args.key?(:semantic_chunking_group_size) end |