Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Response message for the ProcessDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessResponse

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessResponse.



9030
9031
9032
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property document



9016
9017
9018
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9016

def document
  @document
end

#human_review_operationString

The name of the operation triggered by the processed document. If the human review process isn't triggered, this field is empty. It has the same response type and metadata as the long-running operation returned by ReviewDocument. Corresponds to the JSON property humanReviewOperation

Returns:

  • (String)


9023
9024
9025
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9023

def human_review_operation
  @human_review_operation
end

#human_review_statusGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3HumanReviewStatus

The status of human review on a processed document. Corresponds to the JSON property humanReviewStatus



9028
9029
9030
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9028

def human_review_status
  @human_review_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9035
9036
9037
9038
9039
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9035

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @human_review_operation = args[:human_review_operation] if args.key?(:human_review_operation)
  @human_review_status = args[:human_review_status] if args.key?(:human_review_status)
end