Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Information about the upcoming deprecation of this processor version.
Instance Attribute Summary collapse
-
#deprecation_time ⇒ String
The time at which this processor version will be deprecated.
-
#replacement_processor_version ⇒ String
If set, the processor version that will be used as a replacement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo.
9319 9320 9321 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deprecation_time ⇒ String
The time at which this processor version will be deprecated.
Corresponds to the JSON property deprecationTime
9312 9313 9314 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9312 def deprecation_time @deprecation_time end |
#replacement_processor_version ⇒ String
If set, the processor version that will be used as a replacement.
Corresponds to the JSON property replacementProcessorVersion
9317 9318 9319 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9317 def replacement_processor_version @replacement_processor_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9324 9325 9326 9327 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9324 def update!(**args) @deprecation_time = args[:deprecation_time] if args.key?(:deprecation_time) @replacement_processor_version = args[:replacement_processor_version] if args.key?(:replacement_processor_version) end |