Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Information about Generative AI model-based processor versions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo.



9386
9387
9388
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_gen_ai_model_infoGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Information for a custom Generative AI model created by the user. These are created with Create New Version in either the Call foundation model or Fine tuning tabs. Corresponds to the JSON property customGenAiModelInfo



9379
9380
9381
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9379

def custom_gen_ai_model_info
  @custom_gen_ai_model_info
end

#foundation_gen_ai_model_infoGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Information for a pretrained Google-managed foundation model. Corresponds to the JSON property foundationGenAiModelInfo



9384
9385
9386
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9384

def foundation_gen_ai_model_info
  @foundation_gen_ai_model_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9391
9392
9393
9394
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9391

def update!(**args)
  @custom_gen_ai_model_info = args[:custom_gen_ai_model_info] if args.key?(:custom_gen_ai_model_info)
  @foundation_gen_ai_model_info = args[:foundation_gen_ai_model_info] if args.key?(:foundation_gen_ai_model_info)
end