Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Information for a custom Generative AI model created by the user. These are created with Create New Version in either the Call foundation model or Fine tuning tabs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo.



9406
9407
9408
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_processor_version_idString

The base processor version ID for the custom model. Corresponds to the JSON property baseProcessorVersionId

Returns:

  • (String)


9399
9400
9401
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9399

def base_processor_version_id
  @base_processor_version_id
end

#custom_model_typeString

The type of custom model created by the user. Corresponds to the JSON property customModelType

Returns:

  • (String)


9404
9405
9406
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9404

def custom_model_type
  @custom_model_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9411
9412
9413
9414
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9411

def update!(**args)
  @base_processor_version_id = args[:base_processor_version_id] if args.key?(:base_processor_version_id)
  @custom_model_type = args[:custom_model_type] if args.key?(:custom_model_type)
end