Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Information for a pretrained Google-managed foundation model.
Instance Attribute Summary collapse
-
#finetuning_allowed ⇒ Boolean
(also: #finetuning_allowed?)
Whether fine tuning is allowed for this base processor version.
-
#min_train_labeled_documents ⇒ Fixnum
The minimum number of labeled documents in the training dataset required for fine tuning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo.
9433 9434 9435 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finetuning_allowed ⇒ Boolean Also known as: finetuning_allowed?
Whether fine tuning is allowed for this base processor version.
Corresponds to the JSON property finetuningAllowed
9424 9425 9426 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9424 def finetuning_allowed @finetuning_allowed end |
#min_train_labeled_documents ⇒ Fixnum
The minimum number of labeled documents in the training dataset required for
fine tuning.
Corresponds to the JSON property minTrainLabeledDocuments
9431 9432 9433 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9431 def min_train_labeled_documents @min_train_labeled_documents end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9438 9439 9440 9441 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9438 def update!(**args) @finetuning_allowed = args[:finetuning_allowed] if args.key?(:finetuning_allowed) @min_train_labeled_documents = args[:min_train_labeled_documents] if args.key?(:min_train_labeled_documents) end |