Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3RevisionRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The revision reference specifies which revision on the document to read.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3RevisionRef

Returns a new instance of GoogleCloudDocumentaiV1beta3RevisionRef.



9643
9644
9645
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latest_processor_versionString

Reads the revision generated by the processor version. The format takes the full resource name of processor version. projects/project/locations/ location/processors/processor/processorVersions/processorVersion` Corresponds to the JSON propertylatestProcessorVersion`

Returns:

  • (String)


9631
9632
9633
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9631

def latest_processor_version
  @latest_processor_version
end

#revision_caseString

Reads the revision by the predefined case. Corresponds to the JSON property revisionCase

Returns:

  • (String)


9636
9637
9638
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9636

def revision_case
  @revision_case
end

#revision_idString

Reads the revision given by the id. Corresponds to the JSON property revisionId

Returns:

  • (String)


9641
9642
9643
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9641

def revision_id
  @revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9648
9649
9650
9651
9652
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9648

def update!(**args)
  @latest_processor_version = args[:latest_processor_version] if args.key?(:latest_processor_version)
  @revision_case = args[:revision_case] if args.key?(:revision_case)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
end