Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3SchemaVersion
constructor
A new instance of GoogleCloudDocumentaiV1beta3SchemaVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3SchemaVersion
Returns a new instance of GoogleCloudDocumentaiV1beta3SchemaVersion.
9768 9769 9770 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the SchemaVersion was created.
Corresponds to the JSON property createTime
9745 9746 9747 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9745 def create_time @create_time end |
#display_name ⇒ String
Required. The user-defined name of the SchemaVersion.
Corresponds to the JSON property displayName
9750 9751 9752 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9750 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. The gcp_name_short labels for the SchemaVersion.
Corresponds to the JSON property labels
9755 9756 9757 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9755 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the SchemaVersion. Format: projects/project
/locations/location/schemas/schema/schemaVersions/schema_version`
Corresponds to the JSON propertyname`
9761 9762 9763 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9761 def name @name end |
#schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property schema
9766 9767 9768 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9766 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9773 9774 9775 9776 9777 9778 9779 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9773 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) end |