Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Request message for the TrainProcessorVersion method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequest

Returns a new instance of GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequest.



9941
9942
9943
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_processor_versionString

Optional. The processor version to use as a base for training. This processor version must be a child of parent. Format: projects/project/locations/ location/processors/processor/processorVersions/processorVersion`. Corresponds to the JSON propertybaseProcessorVersion`

Returns:

  • (String)


9910
9911
9912
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9910

def base_processor_version
  @base_processor_version
end

#custom_document_extraction_optionsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestCustomDocumentExtractionOptions

Options to control the training of the Custom Document Extraction (CDE) Processor. Corresponds to the JSON property customDocumentExtractionOptions



9916
9917
9918
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9916

def custom_document_extraction_options
  @custom_document_extraction_options
end

#document_schemaGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property documentSchema



9921
9922
9923
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9921

def document_schema
  @document_schema
end

#foundation_model_tuning_optionsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestFoundationModelTuningOptions

Options to control foundation model tuning of the processor. Corresponds to the JSON property foundationModelTuningOptions



9926
9927
9928
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9926

def foundation_model_tuning_options
  @foundation_model_tuning_options
end

#input_dataGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestInputData

The input data used to train a new ProcessorVersion. Corresponds to the JSON property inputData



9931
9932
9933
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9931

def input_data
  @input_data
end

#processor_versionGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersion

A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version. Corresponds to the JSON property processorVersion



9939
9940
9941
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9939

def processor_version
  @processor_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9946
9947
9948
9949
9950
9951
9952
9953
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9946

def update!(**args)
  @base_processor_version = args[:base_processor_version] if args.key?(:base_processor_version)
  @custom_document_extraction_options = args[:custom_document_extraction_options] if args.key?(:custom_document_extraction_options)
  @document_schema = args[:document_schema] if args.key?(:document_schema)
  @foundation_model_tuning_options = args[:foundation_model_tuning_options] if args.key?(:foundation_model_tuning_options)
  @input_data = args[:input_data] if args.key?(:input_data)
  @processor_version = args[:processor_version] if args.key?(:processor_version)
end