Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestFoundationModelTuningOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Options to control foundation model tuning of the processor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestFoundationModelTuningOptions

Returns a new instance of GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestFoundationModelTuningOptions.



10042
10043
10044
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#learning_rate_multiplierFloat

Optional. The multiplier to apply to the recommended learning rate. Valid values are between 0.1 and 10. If not provided, recommended learning rate will be used. Corresponds to the JSON property learningRateMultiplier

Returns:

  • (Float)


10025
10026
10027
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10025

def learning_rate_multiplier
  @learning_rate_multiplier
end

#previous_fine_tuned_processor_version_nameString

Optional. Resource name of a previously fine tuned version id to copy the overwritten configs from. The base_processor_version should be newer than the base processor version used to fine tune this provided processor version. Format: projects/project/locations/location/processors/processor/ processorVersions/processorVersion`. Corresponds to the JSON propertypreviousFineTunedProcessorVersionName`

Returns:

  • (String)


10034
10035
10036
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10034

def previous_fine_tuned_processor_version_name
  @previous_fine_tuned_processor_version_name
end

#train_stepsFixnum

Optional. The number of steps to run for model tuning. Valid values are between 1 and 400. If not provided, recommended steps will be used. Corresponds to the JSON property trainSteps

Returns:

  • (Fixnum)


10040
10041
10042
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10040

def train_steps
  @train_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10047
10048
10049
10050
10051
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10047

def update!(**args)
  @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier)
  @previous_fine_tuned_processor_version_name = args[:previous_fine_tuned_processor_version_name] if args.key?(:previous_fine_tuned_processor_version_name)
  @train_steps = args[:train_steps] if args.key?(:train_steps)
end