Class: Google::Apis::DocumentaiV1beta3::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



10251
10252
10253
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10236
10237
10238
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10236

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::DocumentaiV1beta3::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



10241
10242
10243
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10241

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


10249
10250
10251
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10249

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10256
10257
10258
10259
10260
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10256

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end