Class: Google::Apis::DocumentaiV1beta3::GoogleTypeMoney

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Represents an amount of money with its currency type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleTypeMoney

Returns a new instance of GoogleTypeMoney.



10672
10673
10674
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#currency_codeString

The three-letter currency code defined in ISO 4217. Corresponds to the JSON property currencyCode

Returns:

  • (String)


10655
10656
10657
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10655

def currency_code
  @currency_code
end

#nanosFixnum

Number of nano (10^-9) units of the amount. The value must be between -999,999, 999 and +999,999,999 inclusive. If units is positive, nanos must be positive or zero. If units is zero, nanos can be positive, zero, or negative. If units is negative, nanos must be negative or zero. For example $-1.75 is represented as units=-1 and nanos=-750,000,000. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


10664
10665
10666
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10664

def nanos
  @nanos
end

#unitsFixnum

The whole units of the amount. For example if currencyCode is "USD", then 1 unit is one US dollar. Corresponds to the JSON property units

Returns:

  • (Fixnum)


10670
10671
10672
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10670

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10677
10678
10679
10680
10681
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10677

def update!(**args)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @nanos = args[:nanos] if args.key?(:nanos)
  @units = args[:units] if args.key?(:units)
end