Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The status of each individual document in the import process.
Instance Attribute Summary collapse
-
#input_gcs_source ⇒ String
The source Cloud Storage URI of the document.
-
#output_document_id ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentId
Document Identifier.
-
#output_gcs_destination ⇒ String
The output_gcs_destination of the processed document if it was successful, otherwise empty.
-
#status ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus
Returns a new instance of GoogleCloudDocumentaiUiv1beta3ImportDocumentsMetadataIndividualImportStatus.
1759 1760 1761 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_gcs_source ⇒ String
The source Cloud Storage URI of the document.
Corresponds to the JSON property inputGcsSource
1736 1737 1738 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1736 def input_gcs_source @input_gcs_source end |
#output_document_id ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3DocumentId
Document Identifier.
Corresponds to the JSON property outputDocumentId
1741 1742 1743 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1741 def output_document_id @output_document_id end |
#output_gcs_destination ⇒ String
The output_gcs_destination of the processed document if it was successful,
otherwise empty.
Corresponds to the JSON property outputGcsDestination
1747 1748 1749 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1747 def output_gcs_destination @output_gcs_destination end |
#status ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
1757 1758 1759 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1757 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1764 1765 1766 1767 1768 1769 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 1764 def update!(**args) @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source) @output_document_id = args[:output_document_id] if args.key?(:output_document_id) @output_gcs_destination = args[:output_gcs_destination] if args.key?(:output_gcs_destination) @status = args[:status] if args.key?(:status) end |