Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Information for a custom Generative AI model created by the user. These are
created with Create New Version in either the Call foundation model or
Fine tuning tabs.
Instance Attribute Summary collapse
-
#base_processor_version_id ⇒ String
The base processor version ID for the custom model.
-
#custom_model_type ⇒ String
The type of custom model created by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo
Returns a new instance of GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo.
2129 2130 2131 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_processor_version_id ⇒ String
The base processor version ID for the custom model.
Corresponds to the JSON property baseProcessorVersionId
2122 2123 2124 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2122 def base_processor_version_id @base_processor_version_id end |
#custom_model_type ⇒ String
The type of custom model created by the user.
Corresponds to the JSON property customModelType
2127 2128 2129 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2127 def custom_model_type @custom_model_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2134 2135 2136 2137 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2134 def update!(**args) @base_processor_version_id = args[:base_processor_version_id] if args.key?(:base_processor_version_id) @custom_model_type = args[:custom_model_type] if args.key?(:custom_model_type) end |