Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Information for a pretrained Google-managed foundation model.
Instance Attribute Summary collapse
-
#finetuning_allowed ⇒ Boolean
(also: #finetuning_allowed?)
Whether finetuning is allowed for this base processor version.
-
#min_train_labeled_documents ⇒ Fixnum
The minimum number of labeled documents in the training dataset required for finetuning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo
Returns a new instance of GoogleCloudDocumentaiUiv1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo.
2156 2157 2158 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finetuning_allowed ⇒ Boolean Also known as: finetuning_allowed?
Whether finetuning is allowed for this base processor version.
Corresponds to the JSON property finetuningAllowed
2147 2148 2149 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2147 def finetuning_allowed @finetuning_allowed end |
#min_train_labeled_documents ⇒ Fixnum
The minimum number of labeled documents in the training dataset required for
finetuning.
Corresponds to the JSON property minTrainLabeledDocuments
2154 2155 2156 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2154 def min_train_labeled_documents @min_train_labeled_documents end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2161 2162 2163 2164 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2161 def update!(**args) @finetuning_allowed = args[:finetuning_allowed] if args.key?(:finetuning_allowed) @min_train_labeled_documents = args[:min_train_labeled_documents] if args.key?(:min_train_labeled_documents) end |