Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3PropertyMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3PropertyMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Metadata about a property.
Instance Attribute Summary collapse
-
#field_extraction_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3FieldExtractionMetadata
Metadata for how this field value is extracted.
-
#field_tier_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3FieldTierMetadata
Metadata for the field tier of a property.
-
#human_review_labeling_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewLabelingMetadata
Metadata for human review labeling config.
-
#human_review_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata
Metadata for Human Review config.
-
#inactive ⇒ Boolean
(also: #inactive?)
Whether the property should be considered as "inactive".
-
#schema_editability_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SchemaEditabilityMetadata
Metadata that specifies whether a label is editable and reasons why.
-
#schema_inference_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SchemaInferenceMetadata
Metadata for schema inference.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3PropertyMetadata
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3PropertyMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3PropertyMetadata
Returns a new instance of GoogleCloudDocumentaiUiv1beta3PropertyMetadata.
2209 2210 2211 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_extraction_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3FieldExtractionMetadata
Metadata for how this field value is extracted.
Corresponds to the JSON property fieldExtractionMetadata
2174 2175 2176 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2174 def @field_extraction_metadata end |
#field_tier_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3FieldTierMetadata
Metadata for the field tier of a property.
Corresponds to the JSON property fieldTierMetadata
2179 2180 2181 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2179 def @field_tier_metadata end |
#human_review_labeling_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewLabelingMetadata
Metadata for human review labeling config.
Corresponds to the JSON property humanReviewLabelingMetadata
2184 2185 2186 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2184 def @human_review_labeling_metadata end |
#human_review_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3HumanReviewValidationMetadata
Metadata for Human Review config.
Corresponds to the JSON property humanReviewMetadata
2189 2190 2191 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2189 def @human_review_metadata end |
#inactive ⇒ Boolean Also known as: inactive?
Whether the property should be considered as "inactive".
Corresponds to the JSON property inactive
2194 2195 2196 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2194 def inactive @inactive end |
#schema_editability_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SchemaEditabilityMetadata
Metadata that specifies whether a label is editable and reasons why. These
fields are read-only. Changing these fields has no impact on the backend.
Corresponds to the JSON property schemaEditabilityMetadata
2201 2202 2203 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2201 def @schema_editability_metadata end |
#schema_inference_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiUiv1beta3SchemaInferenceMetadata
Metadata for schema inference. Only used on dataset.schema for schema
inference, can be safely ignored elsewhere.
Corresponds to the JSON property schemaInferenceMetadata
2207 2208 2209 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2207 def @schema_inference_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2214 2215 2216 2217 2218 2219 2220 2221 2222 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2214 def update!(**args) @field_extraction_metadata = args[:field_extraction_metadata] if args.key?(:field_extraction_metadata) @field_tier_metadata = args[:field_tier_metadata] if args.key?(:field_tier_metadata) @human_review_labeling_metadata = args[:human_review_labeling_metadata] if args.key?(:human_review_labeling_metadata) @human_review_metadata = args[:human_review_metadata] if args.key?(:human_review_metadata) @inactive = args[:inactive] if args.key?(:inactive) @schema_editability_metadata = args[:schema_editability_metadata] if args.key?(:schema_editability_metadata) @schema_inference_metadata = args[:schema_inference_metadata] if args.key?(:schema_inference_metadata) end |