Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The status of a each individual document in the batch process.
Instance Attribute Summary collapse
-
#human_review_status ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1HumanReviewStatus
The status of human review on a processed document.
-
#input_gcs_source ⇒ String
The source of the document, same as the input_gcs_source field in the request when the batch process started.
-
#output_gcs_destination ⇒ String
The Cloud Storage output destination (in the request as DocumentOutputConfig. GcsOutputConfig.gcs_uri) of the processed document if it was successful, otherwise empty.
-
#status ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
constructor
A new instance of GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
Returns a new instance of GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus.
2953 2954 2955 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#human_review_status ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1HumanReviewStatus
The status of human review on a processed document.
Corresponds to the JSON property humanReviewStatus
2928 2929 2930 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2928 def human_review_status @human_review_status end |
#input_gcs_source ⇒ String
The source of the document, same as the input_gcs_source field in the request
when the batch process started.
Corresponds to the JSON property inputGcsSource
2934 2935 2936 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2934 def input_gcs_source @input_gcs_source end |
#output_gcs_destination ⇒ String
The Cloud Storage output destination (in the request as DocumentOutputConfig.
GcsOutputConfig.gcs_uri) of the processed document if it was successful,
otherwise empty.
Corresponds to the JSON property outputGcsDestination
2941 2942 2943 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2941 def output_gcs_destination @output_gcs_destination end |
#status ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
2951 2952 2953 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2951 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2958 2959 2960 2961 2962 2963 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 2958 def update!(**args) @human_review_status = args[:human_review_status] if args.key?(:human_review_status) @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source) @output_gcs_destination = args[:output_gcs_destination] if args.key?(:output_gcs_destination) @status = args[:status] if args.key?(:status) end |