Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Request message for BatchProcessDocuments.
Instance Attribute Summary collapse
-
#document_output_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentOutputConfig
Config that controls the output of documents.
-
#input_configs ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig>
The input config for each single document in the batch process.
-
#input_documents ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchDocumentsInputConfig
The common config to specify a set of documents used as input.
-
#labels ⇒ Hash<String,String>
Optional.
-
#output_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchOutputConfig
The output configuration in the BatchProcessDocuments method.
-
#process_options ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptions
Options for Process API Corresponds to the JSON property
processOptions. -
#skip_human_review ⇒ Boolean
(also: #skip_human_review?)
Whether human review should be skipped for this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchProcessRequest
constructor
A new instance of GoogleCloudDocumentaiV1beta3BatchProcessRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchProcessRequest
Returns a new instance of GoogleCloudDocumentaiV1beta3BatchProcessRequest.
3799 3800 3801 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_output_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentOutputConfig
Config that controls the output of documents. All documents will be written as
a JSON file.
Corresponds to the JSON property documentOutputConfig
3762 3763 3764 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3762 def document_output_config @document_output_config end |
#input_configs ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchInputConfig>
The input config for each single document in the batch process.
Corresponds to the JSON property inputConfigs
3767 3768 3769 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3767 def input_configs @input_configs end |
#input_documents ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchDocumentsInputConfig
The common config to specify a set of documents used as input.
Corresponds to the JSON property inputDocuments
3772 3773 3774 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3772 def input_documents @input_documents end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. Label keys
and values can be no longer than 63 characters (Unicode codepoints) and can
only contain lowercase letters, numeric characters, underscores, and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter.
Corresponds to the JSON property labels
3781 3782 3783 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3781 def labels @labels end |
#output_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchProcessRequestBatchOutputConfig
The output configuration in the BatchProcessDocuments method.
Corresponds to the JSON property outputConfig
3786 3787 3788 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3786 def output_config @output_config end |
#process_options ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptions
Options for Process API
Corresponds to the JSON property processOptions
3791 3792 3793 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3791 def @process_options end |
#skip_human_review ⇒ Boolean Also known as: skip_human_review?
Whether human review should be skipped for this request. Default to false.
Corresponds to the JSON property skipHumanReview
3796 3797 3798 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3796 def skip_human_review @skip_human_review end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3804 3805 3806 3807 3808 3809 3810 3811 3812 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 3804 def update!(**args) @document_output_config = args[:document_output_config] if args.key?(:document_output_config) @input_configs = args[:input_configs] if args.key?(:input_configs) @input_documents = args[:input_documents] if args.key?(:input_documents) @labels = args[:labels] if args.key?(:labels) @output_config = args[:output_config] if args.key?(:output_config) @process_options = args[:process_options] if args.key?(:process_options) @skip_human_review = args[:skip_human_review] if args.key?(:skip_human_review) end |