Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Document

Returns a new instance of GoogleCloudDocumentaiV1beta3Document.



4376
4377
4378
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_assetsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentBlobAsset>

Optional. The blob assets in this document. This is used to store the content of the inline blobs in this document, e.g. image bytes, such that it can be referenced by other fields in the document via asset id. Corresponds to the JSON property blobAssets



4261
4262
4263
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4261

def blob_assets
  @blob_assets
end

#chunked_documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocument

Represents the chunks that the document is divided into. Corresponds to the JSON property chunkedDocument



4266
4267
4268
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4266

def chunked_document
  @chunked_document
end

#contentString

Optional. Inline document content, represented as a stream of bytes. Note: As with all bytes fields, protobuffers use a pure binary representation, whereas JSON representations use base64. Corresponds to the JSON property content NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4274
4275
4276
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4274

def content
  @content
end

#docidString

Optional. An internal identifier for document. Should be loggable (no PII). Corresponds to the JSON property docid

Returns:

  • (String)


4279
4280
4281
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4279

def docid
  @docid
end

#document_layoutGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayout

Represents the parsed layout of a document as a collection of blocks that the document is divided into. Corresponds to the JSON property documentLayout



4285
4286
4287
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4285

def document_layout
  @document_layout
end

#entitiesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntity>

A list of entities detected on Document.text. For document shards, entities in this list may cross shard boundaries. Corresponds to the JSON property entities



4291
4292
4293
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4291

def entities
  @entities
end

#entities_revision_idString

The entity revision id that document.entities field is based on. If this field is set and entities_revisions is not empty, the entities in document. entities field are the entities in the entity revision with this id and document.entity_validation_output field is the entity_validation_output field in this entity revision. Corresponds to the JSON property entitiesRevisionId

Returns:

  • (String)


4300
4301
4302
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4300

def entities_revision_id
  @entities_revision_id
end

#entities_revisionsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntitiesRevision>

A list of entity revisions. The entity revisions are appended to the document in the processing order. This field can be used for comparing the entity extraction results at different stages of the processing. Corresponds to the JSON property entitiesRevisions



4307
4308
4309
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4307

def entities_revisions
  @entities_revisions
end

#entity_relationsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityRelation>

Placeholder. Relationship among Document.entities. Corresponds to the JSON property entityRelations



4312
4313
4314
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4312

def entity_relations
  @entity_relations
end

#entity_validation_outputGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutput

The output of the validation given the document and the validation rules. Corresponds to the JSON property entityValidationOutput



4317
4318
4319
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4317

def entity_validation_output
  @entity_validation_output
end

#errorGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4327
4328
4329
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4327

def error
  @error
end

#mime_typeString

An IANA published media type (MIME type). Corresponds to the JSON property mimeType

Returns:

  • (String)


4333
4334
4335
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4333

def mime_type
  @mime_type
end

#pagesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPage>

Visual page layout for the Document. Corresponds to the JSON property pages



4338
4339
4340
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4338

def pages
  @pages
end

#revisionsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevision>

Placeholder. Revision history of this document. Corresponds to the JSON property revisions



4343
4344
4345
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4343

def revisions
  @revisions
end

#shard_infoGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentShardInfo

For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is. Corresponds to the JSON property shardInfo



4349
4350
4351
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4349

def shard_info
  @shard_info
end

#textString

Optional. UTF-8 encoded text in reading order from the document. Corresponds to the JSON property text

Returns:

  • (String)


4354
4355
4356
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4354

def text
  @text
end

#text_changesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentTextChange>

Placeholder. A list of text corrections made to Document.text. This is usually used for annotating corrections to OCR mistakes. Text changes for a given revision may not overlap with each other. Corresponds to the JSON property textChanges



4361
4362
4363
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4361

def text_changes
  @text_changes
end

#text_stylesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentStyle>

Styles for the Document.text. Corresponds to the JSON property textStyles



4366
4367
4368
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4366

def text_styles
  @text_styles
end

#uriString

Optional. Currently supports Google Cloud Storage URI of the form gs:// bucket_name/object_name. Object versioning is not supported. For more information, refer to Google Cloud Storage Request URIs. Corresponds to the JSON property uri

Returns:

  • (String)


4374
4375
4376
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4374

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4381

def update!(**args)
  @blob_assets = args[:blob_assets] if args.key?(:blob_assets)
  @chunked_document = args[:chunked_document] if args.key?(:chunked_document)
  @content = args[:content] if args.key?(:content)
  @docid = args[:docid] if args.key?(:docid)
  @document_layout = args[:document_layout] if args.key?(:document_layout)
  @entities = args[:entities] if args.key?(:entities)
  @entities_revision_id = args[:entities_revision_id] if args.key?(:entities_revision_id)
  @entities_revisions = args[:entities_revisions] if args.key?(:entities_revisions)
  @entity_relations = args[:entity_relations] if args.key?(:entity_relations)
  @entity_validation_output = args[:entity_validation_output] if args.key?(:entity_validation_output)
  @error = args[:error] if args.key?(:error)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @pages = args[:pages] if args.key?(:pages)
  @revisions = args[:revisions] if args.key?(:revisions)
  @shard_info = args[:shard_info] if args.key?(:shard_info)
  @text = args[:text] if args.key?(:text)
  @text_changes = args[:text_changes] if args.key?(:text_changes)
  @text_styles = args[:text_styles] if args.key?(:text_styles)
  @uri = args[:uri] if args.key?(:uri)
end