Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentBlobAsset
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentBlobAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Represents a blob asset. It's used to store the content of the inline blob in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset ID.
Instance Attribute Summary collapse
-
#asset_id ⇒ String
Optional.
-
#content ⇒ String
Optional.
-
#mime_type ⇒ String
The mime type of the blob asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentBlobAsset
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentBlobAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentBlobAsset
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentBlobAsset.
4427 4428 4429 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_id ⇒ String
Optional. The id of the blob asset.
Corresponds to the JSON property assetId
4413 4414 4415 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4413 def asset_id @asset_id end |
#content ⇒ String
Optional. The content of the blob asset, for example, image bytes.
Corresponds to the JSON property content
NOTE: Values are automatically base64 encoded/decoded in the client library.
4419 4420 4421 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4419 def content @content end |
#mime_type ⇒ String
The mime type of the blob asset. An IANA published media type (MIME type).
Corresponds to the JSON property mimeType
4425 4426 4427 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4425 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4432 4433 4434 4435 4436 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4432 def update!(**args) @asset_id = args[:asset_id] if args.key?(:asset_id) @content = args[:content] if args.key?(:content) @mime_type = args[:mime_type] if args.key?(:mime_type) end |