Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunk
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Represents a chunk.
Instance Attribute Summary collapse
-
#chunk_fields ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkField>
Chunk fields inside this chunk.
-
#chunk_id ⇒ String
ID of the chunk.
-
#content ⇒ String
Text content of the chunk.
-
#page_footers ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkPageFooter>
Page footers associated with the chunk.
-
#page_headers ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkPageHeader>
Page headers associated with the chunk.
-
#page_span ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#source_block_ids ⇒ Array<String>
Unused.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunk
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunk
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunk.
4516 4517 4518 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_fields ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkField>
Chunk fields inside this chunk.
Corresponds to the JSON property chunkFields
4484 4485 4486 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4484 def chunk_fields @chunk_fields end |
#chunk_id ⇒ String
ID of the chunk.
Corresponds to the JSON property chunkId
4489 4490 4491 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4489 def chunk_id @chunk_id end |
#content ⇒ String
Text content of the chunk.
Corresponds to the JSON property content
4494 4495 4496 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4494 def content @content end |
#page_footers ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkPageFooter>
Page footers associated with the chunk.
Corresponds to the JSON property pageFooters
4499 4500 4501 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4499 def @page_footers end |
#page_headers ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkPageHeader>
Page headers associated with the chunk.
Corresponds to the JSON property pageHeaders
4504 4505 4506 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4504 def page_headers @page_headers end |
#page_span ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
4509 4510 4511 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4509 def page_span @page_span end |
#source_block_ids ⇒ Array<String>
Unused.
Corresponds to the JSON property sourceBlockIds
4514 4515 4516 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4514 def source_block_ids @source_block_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4521 4522 4523 4524 4525 4526 4527 4528 4529 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4521 def update!(**args) @chunk_fields = args[:chunk_fields] if args.key?(:chunk_fields) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) @content = args[:content] if args.key?(:content) @page_footers = args[:page_footers] if args.key?(:page_footers) @page_headers = args[:page_headers] if args.key?(:page_headers) @page_span = args[:page_span] if args.key?(:page_span) @source_block_ids = args[:source_block_ids] if args.key?(:source_block_ids) end |