Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkImageChunkField
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkImageChunkField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The image chunk field in the chunk.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
-
#blob_asset_id ⇒ String
Optional.
-
#data_uri ⇒ String
Optional.
-
#gcs_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkImageChunkField
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkImageChunkField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkImageChunkField
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentChunkedDocumentChunkImageChunkField.
4660 4661 4662 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentAnnotations
Represents the annotation of a block or a chunk.
Corresponds to the JSON property annotations
4640 4641 4642 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4640 def annotations @annotations end |
#blob_asset_id ⇒ String
Optional. Asset id of the inline image. If set, find the image content in the
blob_assets field.
Corresponds to the JSON property blobAssetId
4646 4647 4648 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4646 def blob_asset_id @blob_asset_id end |
#data_uri ⇒ String
Optional. Data uri of the image. It is composed of four parts: a prefix (data:)
, a MIME type indicating the type of data, an optional base64 token if non-
textual, and the data itself: data:,
Corresponds to the JSON property dataUri
4653 4654 4655 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4653 def data_uri @data_uri end |
#gcs_uri ⇒ String
Optional. Google Cloud Storage uri of the image.
Corresponds to the JSON property gcsUri
4658 4659 4660 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4658 def gcs_uri @gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4665 4666 4667 4668 4669 4670 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4665 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @blob_asset_id = args[:blob_asset_id] if args.key?(:blob_asset_id) @data_uri = args[:data_uri] if args.key?(:data_uri) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) end |