Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Represents a block. A block could be one of the various types (text, table, list) supported.
Instance Attribute Summary collapse
-
#block_id ⇒ String
ID of the block.
-
#bounding_box ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BoundingPoly
A bounding polygon for the detected image annotation.
-
#image_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock
Represents an image type block.
-
#list_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock
Represents a list type block.
-
#page_span ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan
Represents where the block starts and ends in the document.
-
#table_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
Represents a table type block.
-
#text_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
Represents a text type block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlock.
4752 4753 4754 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block_id ⇒ String
ID of the block.
Corresponds to the JSON property blockId
4720 4721 4722 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4720 def block_id @block_id end |
#bounding_box ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingBox
4725 4726 4727 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4725 def bounding_box @bounding_box end |
#image_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock
Represents an image type block.
Corresponds to the JSON property imageBlock
4730 4731 4732 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4730 def image_block @image_block end |
#list_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock
Represents a list type block.
Corresponds to the JSON property listBlock
4735 4736 4737 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4735 def list_block @list_block end |
#page_span ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan
Represents where the block starts and ends in the document.
Corresponds to the JSON property pageSpan
4740 4741 4742 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4740 def page_span @page_span end |
#table_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
Represents a table type block.
Corresponds to the JSON property tableBlock
4745 4746 4747 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4745 def table_block @table_block end |
#text_block ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
Represents a text type block.
Corresponds to the JSON property textBlock
4750 4751 4752 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4750 def text_block @text_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4757 4758 4759 4760 4761 4762 4763 4764 4765 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 4757 def update!(**args) @block_id = args[:block_id] if args.key?(:block_id) @bounding_box = args[:bounding_box] if args.key?(:bounding_box) @image_block = args[:image_block] if args.key?(:image_block) @list_block = args[:list_block] if args.key?(:list_block) @page_span = args[:page_span] if args.key?(:page_span) @table_block = args[:table_block] if args.key?(:table_block) @text_block = args[:text_block] if args.key?(:text_block) end |