Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Validation result for a single validation rule.
Instance Attribute Summary collapse
-
#rule ⇒ String
Optional.
-
#rule_description ⇒ String
The description of the validation rule.
-
#rule_name ⇒ String
The display name of the validation rule.
-
#validation_details ⇒ String
The detailed information of the running the validation process using the entity from the document based on the validation rule.
-
#validation_result_type ⇒ String
The result of the validation rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentEntityValidationOutputValidationResult.
5346 5347 5348 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rule ⇒ String
Optional. The name of the rule resource that is used for validation. Format:
projects/project/locations/location/rules/rule`
Corresponds to the JSON propertyrule`
5323 5324 5325 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5323 def rule @rule end |
#rule_description ⇒ String
The description of the validation rule.
Corresponds to the JSON property ruleDescription
5328 5329 5330 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5328 def rule_description @rule_description end |
#rule_name ⇒ String
The display name of the validation rule.
Corresponds to the JSON property ruleName
5333 5334 5335 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5333 def rule_name @rule_name end |
#validation_details ⇒ String
The detailed information of the running the validation process using the
entity from the document based on the validation rule.
Corresponds to the JSON property validationDetails
5339 5340 5341 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5339 def validation_details @validation_details end |
#validation_result_type ⇒ String
The result of the validation rule.
Corresponds to the JSON property validationResultType
5344 5345 5346 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5344 def validation_result_type @validation_result_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5351 5352 5353 5354 5355 5356 5357 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5351 def update!(**args) @rule = args[:rule] if args.key?(:rule) @rule_description = args[:rule_description] if args.key?(:rule_description) @rule_name = args[:rule_name] if args.key?(:rule_name) @validation_details = args[:validation_details] if args.key?(:validation_details) @validation_result_type = args[:validation_result_type] if args.key?(:validation_result_type) end |