Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

A page in a Document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPage

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPage.



5657
5658
5659
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocksArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageBlock>

A list of visually detected text blocks on the page. A block has a set of lines (collected into paragraphs) that have a common line-spacing and orientation. Corresponds to the JSON property blocks



5569
5570
5571
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5569

def blocks
  @blocks
end

#detected_barcodesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedBarcode>

A list of detected barcodes. Corresponds to the JSON property detectedBarcodes



5574
5575
5576
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5574

def detected_barcodes
  @detected_barcodes
end

#detected_languagesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5579
5580
5581
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5579

def detected_languages
  @detected_languages
end

#dimensionGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDimension

Dimension for the page. Corresponds to the JSON property dimension



5584
5585
5586
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5584

def dimension
  @dimension
end

#form_fieldsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageFormField>

A list of visually detected form fields on the page. Corresponds to the JSON property formFields



5589
5590
5591
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5589

def form_fields
  @form_fields
end

#imageGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageImage

Rendered image contents for this page. Corresponds to the JSON property image



5594
5595
5596
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5594

def image
  @image
end

#image_quality_scoresGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageImageQualityScores

Image quality scores for the page image. Corresponds to the JSON property imageQualityScores



5599
5600
5601
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5599

def image_quality_scores
  @image_quality_scores
end

#layoutGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5604
5605
5606
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5604

def layout
  @layout
end

#linesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLine>

A list of visually detected text lines on the page. A collection of tokens that a human would perceive as a line. Corresponds to the JSON property lines



5610
5611
5612
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5610

def lines
  @lines
end

#page_numberFixnum

1-based index for current Page in a parent Document. Useful when a page is taken out of a Document for individual processing. Corresponds to the JSON property pageNumber

Returns:

  • (Fixnum)


5616
5617
5618
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5616

def page_number
  @page_number
end

#paragraphsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageParagraph>

A list of visually detected text paragraphs on the page. A collection of lines that a human would perceive as a paragraph. Corresponds to the JSON property paragraphs



5622
5623
5624
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5622

def paragraphs
  @paragraphs
end

#provenanceGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5628
5629
5630
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5628

def provenance
  @provenance
end

#symbolsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageSymbol>

A list of visually detected symbols on the page. Corresponds to the JSON property symbols



5633
5634
5635
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5633

def symbols
  @symbols
end

#tablesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTable>

A list of visually detected tables on the page. Corresponds to the JSON property tables



5638
5639
5640
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5638

def tables
  @tables
end

#tokensArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageToken>

A list of visually detected tokens on the page. Corresponds to the JSON property tokens



5643
5644
5645
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5643

def tokens
  @tokens
end

#transformsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageMatrix>

Transformation matrices that were applied to the original document image to produce Page.image. Corresponds to the JSON property transforms



5649
5650
5651
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5649

def transforms
  @transforms
end

#visual_elementsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageVisualElement>

A list of detected non-text visual elements e.g. checkbox, signature etc. on the page. Corresponds to the JSON property visualElements



5655
5656
5657
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5655

def visual_elements
  @visual_elements
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5662

def update!(**args)
  @blocks = args[:blocks] if args.key?(:blocks)
  @detected_barcodes = args[:detected_barcodes] if args.key?(:detected_barcodes)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @dimension = args[:dimension] if args.key?(:dimension)
  @form_fields = args[:form_fields] if args.key?(:form_fields)
  @image = args[:image] if args.key?(:image)
  @image_quality_scores = args[:image_quality_scores] if args.key?(:image_quality_scores)
  @layout = args[:layout] if args.key?(:layout)
  @lines = args[:lines] if args.key?(:lines)
  @page_number = args[:page_number] if args.key?(:page_number)
  @paragraphs = args[:paragraphs] if args.key?(:paragraphs)
  @provenance = args[:provenance] if args.key?(:provenance)
  @symbols = args[:symbols] if args.key?(:symbols)
  @tables = args[:tables] if args.key?(:tables)
  @tokens = args[:tokens] if args.key?(:tokens)
  @transforms = args[:transforms] if args.key?(:transforms)
  @visual_elements = args[:visual_elements] if args.key?(:visual_elements)
end