Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Represents a weak reference to a page element within a document.
Instance Attribute Summary collapse
-
#bounding_poly ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BoundingPoly
A bounding polygon for the detected image annotation.
-
#confidence ⇒ Float
Optional.
-
#layout_id ⇒ String
Optional.
-
#layout_type ⇒ String
Optional.
-
#page ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageAnchorPageRef.
5736 5737 5738 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_poly ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingPoly
5711 5712 5713 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5711 def bounding_poly @bounding_poly end |
#confidence ⇒ Float
Optional. Confidence of detected page element, if applicable. Range [0, 1].
Corresponds to the JSON property confidence
5716 5717 5718 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5716 def confidence @confidence end |
#layout_id ⇒ String
Optional. Deprecated. Use PageRef.bounding_poly instead.
Corresponds to the JSON property layoutId
5721 5722 5723 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5721 def layout_id @layout_id end |
#layout_type ⇒ String
Optional. The type of the layout element that is being referenced if any.
Corresponds to the JSON property layoutType
5726 5727 5728 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5726 def layout_type @layout_type end |
#page ⇒ Fixnum
Required. Index into the Document.pages element, for example using Document.
pages to locate the related page element. This field is skipped when its
value is the default 0. See https://developers.google.com/protocol-buffers/
docs/proto3#json.
Corresponds to the JSON property page
5734 5735 5736 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5734 def page @page end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 5741 def update!(**args) @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly) @confidence = args[:confidence] if args.key?(:confidence) @layout_id = args[:layout_id] if args.key?(:layout_id) @layout_type = args[:layout_type] if args.key?(:layout_type) @page = args[:page] if args.key?(:page) end |