Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

A detected token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageToken

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageToken.



6327
6328
6329
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_breakGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTokenDetectedBreak

Detected break at the end of a Token. Corresponds to the JSON property detectedBreak



6304
6305
6306
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6304

def detected_break
  @detected_break
end

#detected_languagesArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



6309
6310
6311
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6309

def detected_languages
  @detected_languages
end

#layoutGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



6314
6315
6316
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6314

def layout
  @layout
end

#provenanceGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



6320
6321
6322
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6320

def provenance
  @provenance
end

#style_infoGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTokenStyleInfo

Font and other text style attributes. Corresponds to the JSON property styleInfo



6325
6326
6327
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6325

def style_info
  @style_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6332
6333
6334
6335
6336
6337
6338
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6332

def update!(**args)
  @detected_break = args[:detected_break] if args.key?(:detected_break)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
  @style_info = args[:style_info] if args.key?(:style_info)
end