Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentPageTokenStyleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Font and other text style attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentPageTokenStyleInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentPageTokenStyleInfo.



6536
6537
6538
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_colorGoogle::Apis::DocumentaiV1beta3::GoogleTypeColor

Represents a color in the RGBA color space. This representation is designed for simplicity of conversion to and from color representations in various languages over compactness. For example, the fields of this representation can be trivially provided to the constructor of java.awt.Color in Java; it can also be trivially provided to UIColor's +colorWithRed:green:blue:alpha method in iOS; and, with just a little work, it can be easily formatted into a CSS rgba() string in JavaScript. This reference page doesn't have information about the absolute color space that should be used to interpret the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default, applications should assume the sRGB color space. When color equality needs to be decided, implementations, unless documented otherwise, treat two colors as equal if all their red, green, blue, and alpha values each differ by at most 1e-5. Example (Java): import com.google.type.Color; // ... public static java. awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ? protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor. getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static Color toProto(java.awt.Color color) float red = (float) color.getRed(); float green = (float) color.getGreen(); float blue = (float) color.getBlue(); float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() . setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue / denominator); int alpha = color.getAlpha(); if (alpha != 255) result. setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) . build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // .. . static UIColor* fromProto(Color* protocolor) float red = [protocolor red]; float green = [protocolor green]; float blue = [protocolor blue]; FloatValue* alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper != nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green: green blue:blue alpha:alpha]; static Color* toProto(UIColor* color) CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:& blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [ result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha < = 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result autorelease]; return result; // ... Example (JavaScript): // ... var protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0; var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0; var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255); var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0. 0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ', ', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue) var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder. push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; / / ... Corresponds to the JSON property backgroundColor



6411
6412
6413
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6411

def background_color
  @background_color
end

#boldBoolean Also known as: bold?

Whether the text is bold (equivalent to font_weight is at least 700). Corresponds to the JSON property bold

Returns:

  • (Boolean)


6416
6417
6418
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6416

def bold
  @bold
end

#font_sizeFixnum

Font size in points (1 point is ¹⁄₇₂ inches). Corresponds to the JSON property fontSize

Returns:

  • (Fixnum)


6422
6423
6424
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6422

def font_size
  @font_size
end

#font_typeString

Name or style of the font. Corresponds to the JSON property fontType

Returns:

  • (String)


6427
6428
6429
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6427

def font_type
  @font_type
end

#font_weightFixnum

TrueType weight on a scale 100 (thin) to 1000 (ultra-heavy). Normal is 400, bold is 700. Corresponds to the JSON property fontWeight

Returns:

  • (Fixnum)


6433
6434
6435
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6433

def font_weight
  @font_weight
end

#handwrittenBoolean Also known as: handwritten?

Whether the text is handwritten. Corresponds to the JSON property handwritten

Returns:

  • (Boolean)


6438
6439
6440
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6438

def handwritten
  @handwritten
end

#italicBoolean Also known as: italic?

Whether the text is italic. Corresponds to the JSON property italic

Returns:

  • (Boolean)


6444
6445
6446
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6444

def italic
  @italic
end

#letter_spacingFloat

Letter spacing in points. Corresponds to the JSON property letterSpacing

Returns:

  • (Float)


6450
6451
6452
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6450

def letter_spacing
  @letter_spacing
end

#pixel_font_sizeFloat

Font size in pixels, equal to unrounded font_size * resolution ÷ 72.0. Corresponds to the JSON property pixelFontSize

Returns:

  • (Float)


6455
6456
6457
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6455

def pixel_font_size
  @pixel_font_size
end

#smallcapsBoolean Also known as: smallcaps?

Whether the text is in small caps. This feature is not supported yet. Corresponds to the JSON property smallcaps

Returns:

  • (Boolean)


6460
6461
6462
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6460

def smallcaps
  @smallcaps
end

#strikeoutBoolean Also known as: strikeout?

Whether the text is strikethrough. This feature is not supported yet. Corresponds to the JSON property strikeout

Returns:

  • (Boolean)


6466
6467
6468
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6466

def strikeout
  @strikeout
end

#subscriptBoolean Also known as: subscript?

Whether the text is a subscript. This feature is not supported yet. Corresponds to the JSON property subscript

Returns:

  • (Boolean)


6472
6473
6474
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6472

def subscript
  @subscript
end

#superscriptBoolean Also known as: superscript?

Whether the text is a superscript. This feature is not supported yet. Corresponds to the JSON property superscript

Returns:

  • (Boolean)


6478
6479
6480
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6478

def superscript
  @superscript
end

#text_colorGoogle::Apis::DocumentaiV1beta3::GoogleTypeColor

Represents a color in the RGBA color space. This representation is designed for simplicity of conversion to and from color representations in various languages over compactness. For example, the fields of this representation can be trivially provided to the constructor of java.awt.Color in Java; it can also be trivially provided to UIColor's +colorWithRed:green:blue:alpha method in iOS; and, with just a little work, it can be easily formatted into a CSS rgba() string in JavaScript. This reference page doesn't have information about the absolute color space that should be used to interpret the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default, applications should assume the sRGB color space. When color equality needs to be decided, implementations, unless documented otherwise, treat two colors as equal if all their red, green, blue, and alpha values each differ by at most 1e-5. Example (Java): import com.google.type.Color; // ... public static java. awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ? protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor. getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static Color toProto(java.awt.Color color) float red = (float) color.getRed(); float green = (float) color.getGreen(); float blue = (float) color.getBlue(); float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() . setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue / denominator); int alpha = color.getAlpha(); if (alpha != 255) result. setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) . build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // .. . static UIColor* fromProto(Color* protocolor) float red = [protocolor red]; float green = [protocolor green]; float blue = [protocolor blue]; FloatValue* alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper != nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green: green blue:blue alpha:alpha]; static Color* toProto(UIColor* color) CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:& blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [ result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha < = 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result autorelease]; return result; // ... Example (JavaScript): // ... var protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0; var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0; var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255); var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0. 0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ', ', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue) var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder. push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; / / ... Corresponds to the JSON property textColor



6528
6529
6530
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6528

def text_color
  @text_color
end

#underlinedBoolean Also known as: underlined?

Whether the text is underlined. Corresponds to the JSON property underlined

Returns:

  • (Boolean)


6533
6534
6535
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6533

def underlined
  @underlined
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6541

def update!(**args)
  @background_color = args[:background_color] if args.key?(:background_color)
  @bold = args[:bold] if args.key?(:bold)
  @font_size = args[:font_size] if args.key?(:font_size)
  @font_type = args[:font_type] if args.key?(:font_type)
  @font_weight = args[:font_weight] if args.key?(:font_weight)
  @handwritten = args[:handwritten] if args.key?(:handwritten)
  @italic = args[:italic] if args.key?(:italic)
  @letter_spacing = args[:letter_spacing] if args.key?(:letter_spacing)
  @pixel_font_size = args[:pixel_font_size] if args.key?(:pixel_font_size)
  @smallcaps = args[:smallcaps] if args.key?(:smallcaps)
  @strikeout = args[:strikeout] if args.key?(:strikeout)
  @subscript = args[:subscript] if args.key?(:subscript)
  @superscript = args[:superscript] if args.key?(:superscript)
  @text_color = args[:text_color] if args.key?(:text_color)
  @underlined = args[:underlined] if args.key?(:underlined)
end