Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenanceParent
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentProvenanceParent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The parent element the current element is based on. Used for referencing/ aligning, removal and replacement operations.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The id of the parent provenance.
-
#index ⇒ Fixnum
The index of the parent item in the corresponding item list (eg. list of entities, properties within entities, etc.) in the parent revision.
-
#revision ⇒ Fixnum
The index of the index into current revision's parent_ids list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentProvenanceParent
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentProvenanceParent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentProvenanceParent
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentProvenanceParent.
6650 6651 6652 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The id of the parent provenance.
Corresponds to the JSON property id
6637 6638 6639 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6637 def id @id end |
#index ⇒ Fixnum
The index of the parent item in the corresponding item list (eg. list of
entities, properties within entities, etc.) in the parent revision.
Corresponds to the JSON property index
6643 6644 6645 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6643 def index @index end |
#revision ⇒ Fixnum
The index of the index into current revision's parent_ids list.
Corresponds to the JSON property revision
6648 6649 6650 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6648 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6655 6656 6657 6658 6659 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6655 def update!(**args) @id = args[:id] if args.key?(:id) @index = args[:index] if args.key?(:index) @revision = args[:revision] if args.key?(:revision) end |