Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Contains past or forward revisions of this document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentRevision

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentRevision.



6708
6709
6710
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

If the change was made by a person specify the name or id of that person. Corresponds to the JSON property agent

Returns:

  • (String)


6669
6670
6671
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6669

def agent
  @agent
end

#create_timeString

The time that the revision was created, internally generated by doc proto storage at the time of create. Corresponds to the JSON property createTime

Returns:

  • (String)


6675
6676
6677
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6675

def create_time
  @create_time
end

#human_reviewGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentRevisionHumanReview

Human Review information of the document. Corresponds to the JSON property humanReview



6680
6681
6682
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6680

def human_review
  @human_review
end

#idString

Id of the revision, internally generated by doc proto storage. Unique within the context of the document. Corresponds to the JSON property id

Returns:

  • (String)


6686
6687
6688
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6686

def id
  @id
end

#parentArray<Fixnum>

The revisions that this revision is based on. This can include one or more parent (when documents are merged.) This field represents the index into the revisions field. Corresponds to the JSON property parent

Returns:

  • (Array<Fixnum>)


6693
6694
6695
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6693

def parent
  @parent
end

#parent_idsArray<String>

The revisions that this revision is based on. Must include all the ids that have anything to do with this revision - eg. there are provenance.parent. revision fields that index into this field. Corresponds to the JSON property parentIds

Returns:

  • (Array<String>)


6700
6701
6702
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6700

def parent_ids
  @parent_ids
end

#processorString

If the annotation was made by processor identify the processor by its resource name. Corresponds to the JSON property processor

Returns:

  • (String)


6706
6707
6708
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6706

def processor
  @processor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6713
6714
6715
6716
6717
6718
6719
6720
6721
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 6713

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
  @create_time = args[:create_time] if args.key?(:create_time)
  @human_review = args[:human_review] if args.key?(:human_review)
  @id = args[:id] if args.key?(:id)
  @parent = args[:parent] if args.key?(:parent)
  @parent_ids = args[:parent_ids] if args.key?(:parent_ids)
  @processor = args[:processor] if args.key?(:processor)
end