Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Evaluation metrics, either in aggregate or about a specific entity.
Instance Attribute Summary collapse
-
#f1_score ⇒ Float
The calculated f1 score.
-
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
-
#false_positives_count ⇒ Fixnum
The amount of false positives.
-
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
-
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
-
#precision ⇒ Float
The calculated precision.
-
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
-
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
-
#recall ⇒ Float
The calculated recall.
-
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
-
#true_positives_count ⇒ Fixnum
The amount of true positives.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMetrics
constructor
A new instance of GoogleCloudDocumentaiV1beta3EvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMetrics
Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationMetrics.
7593 7594 7595 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7593 def initialize(**args) update!(**args) end |
Instance Attribute Details
#f1_score ⇒ Float
The calculated f1 score.
Corresponds to the JSON property f1Score
7541 7542 7543 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7541 def f1_score @f1_score end |
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
Corresponds to the JSON property falseNegativesCount
7546 7547 7548 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7546 def false_negatives_count @false_negatives_count end |
#false_positives_count ⇒ Fixnum
The amount of false positives.
Corresponds to the JSON property falsePositivesCount
7551 7552 7553 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7551 def false_positives_count @false_positives_count end |
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
Corresponds to the JSON property groundTruthDocumentCount
7556 7557 7558 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7556 def ground_truth_document_count @ground_truth_document_count end |
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
Corresponds to the JSON property groundTruthOccurrencesCount
7561 7562 7563 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7561 def ground_truth_occurrences_count @ground_truth_occurrences_count end |
#precision ⇒ Float
The calculated precision.
Corresponds to the JSON property precision
7566 7567 7568 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7566 def precision @precision end |
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
Corresponds to the JSON property predictedDocumentCount
7571 7572 7573 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7571 def predicted_document_count @predicted_document_count end |
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
Corresponds to the JSON property predictedOccurrencesCount
7576 7577 7578 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7576 def predicted_occurrences_count @predicted_occurrences_count end |
#recall ⇒ Float
The calculated recall.
Corresponds to the JSON property recall
7581 7582 7583 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7581 def recall @recall end |
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
Corresponds to the JSON property totalDocumentsCount
7586 7587 7588 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7586 def total_documents_count @total_documents_count end |
#true_positives_count ⇒ Fixnum
The amount of true positives.
Corresponds to the JSON property truePositivesCount
7591 7592 7593 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7591 def true_positives_count @true_positives_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7598 def update!(**args) @f1_score = args[:f1_score] if args.key?(:f1_score) @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count) @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count) @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count) @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count) @precision = args[:precision] if args.key?(:precision) @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count) @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count) @recall = args[:recall] if args.key?(:recall) @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count) @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count) end |