Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Metrics across multiple confidence levels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics

Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationMultiConfidenceMetrics.



7655
7656
7657
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auprcFloat

The calculated area under the precision recall curve (AUPRC), computed by integrating over all confidence thresholds. Corresponds to the JSON property auprc

Returns:

  • (Float)


7621
7622
7623
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7621

def auprc
  @auprc
end

#auprc_exactFloat

The AUPRC for metrics with fuzzy matching disabled, i.e., exact matching only. Corresponds to the JSON property auprcExact

Returns:

  • (Float)


7626
7627
7628
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7626

def auprc_exact
  @auprc_exact
end

#confidence_level_metricsArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationConfidenceLevelMetrics>

Metrics across confidence levels with fuzzy matching enabled. Corresponds to the JSON property confidenceLevelMetrics



7631
7632
7633
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7631

def confidence_level_metrics
  @confidence_level_metrics
end

#confidence_level_metrics_exactArray<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationConfidenceLevelMetrics>

Metrics across confidence levels with only exact matching. Corresponds to the JSON property confidenceLevelMetricsExact



7636
7637
7638
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7636

def confidence_level_metrics_exact
  @confidence_level_metrics_exact
end

#estimated_calibration_errorFloat

The Estimated Calibration Error (ECE) of the confidence of the predicted entities. Corresponds to the JSON property estimatedCalibrationError

Returns:

  • (Float)


7642
7643
7644
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7642

def estimated_calibration_error
  @estimated_calibration_error
end

#estimated_calibration_error_exactFloat

The ECE for the predicted entities with fuzzy matching disabled, i.e., exact matching only. Corresponds to the JSON property estimatedCalibrationErrorExact

Returns:

  • (Float)


7648
7649
7650
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7648

def estimated_calibration_error_exact
  @estimated_calibration_error_exact
end

#metrics_typeString

The metrics type for the label. Corresponds to the JSON property metricsType

Returns:

  • (String)


7653
7654
7655
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7653

def metrics_type
  @metrics_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7660
7661
7662
7663
7664
7665
7666
7667
7668
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7660

def update!(**args)
  @auprc = args[:auprc] if args.key?(:auprc)
  @auprc_exact = args[:auprc_exact] if args.key?(:auprc_exact)
  @confidence_level_metrics = args[:confidence_level_metrics] if args.key?(:confidence_level_metrics)
  @confidence_level_metrics_exact = args[:confidence_level_metrics_exact] if args.key?(:confidence_level_metrics_exact)
  @estimated_calibration_error = args[:estimated_calibration_error] if args.key?(:estimated_calibration_error)
  @estimated_calibration_error_exact = args[:estimated_calibration_error_exact] if args.key?(:estimated_calibration_error_exact)
  @metrics_type = args[:metrics_type] if args.key?(:metrics_type)
end