Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GenerateSchemaVersionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Request message for GenerateSchemaVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3GenerateSchemaVersionRequest

Returns a new instance of GoogleCloudDocumentaiV1beta3GenerateSchemaVersionRequest.



7878
7879
7880
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_schema_versionString

The base schema version name to use for the schema generation. Format: projects/project/locations/location/schemas/schema/schemaVersions/ schema_version` Corresponds to the JSON propertybaseSchemaVersion`

Returns:

  • (String)


7851
7852
7853
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7851

def base_schema_version
  @base_schema_version
end

#gcs_documentsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GcsDocuments

Specifies a set of documents on Cloud Storage. Corresponds to the JSON property gcsDocuments



7856
7857
7858
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7856

def gcs_documents
  @gcs_documents
end

#gcs_prefixGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GcsPrefix

Specifies all documents on Cloud Storage with a common prefix. Corresponds to the JSON property gcsPrefix



7861
7862
7863
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7861

def gcs_prefix
  @gcs_prefix
end

#generate_schema_version_paramsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GenerateSchemaVersionRequestGenerateSchemaVersionParams

The parameters for the schema generation. Corresponds to the JSON property generateSchemaVersionParams



7866
7867
7868
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7866

def generate_schema_version_params
  @generate_schema_version_params
end

#inline_documentsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Documents

A set of inline documents. Corresponds to the JSON property inlineDocuments



7871
7872
7873
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7871

def inline_documents
  @inline_documents
end

#raw_documentsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3RawDocuments

Specifies a set of raw documents. Corresponds to the JSON property rawDocuments



7876
7877
7878
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7876

def raw_documents
  @raw_documents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7883
7884
7885
7886
7887
7888
7889
7890
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7883

def update!(**args)
  @base_schema_version = args[:base_schema_version] if args.key?(:base_schema_version)
  @gcs_documents = args[:gcs_documents] if args.key?(:gcs_documents)
  @gcs_prefix = args[:gcs_prefix] if args.key?(:gcs_prefix)
  @generate_schema_version_params = args[:generate_schema_version_params] if args.key?(:generate_schema_version_params)
  @inline_documents = args[:inline_documents] if args.key?(:inline_documents)
  @raw_documents = args[:raw_documents] if args.key?(:raw_documents)
end