Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GenerateSchemaVersionResponse
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GenerateSchemaVersionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Response message for GenerateSchemaVersion.
Instance Attribute Summary collapse
-
#schema_version ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3GenerateSchemaVersionResponse
constructor
A new instance of GoogleCloudDocumentaiV1beta3GenerateSchemaVersionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3GenerateSchemaVersionResponse
Returns a new instance of GoogleCloudDocumentaiV1beta3GenerateSchemaVersionResponse.
7894 7895 7896 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7894 def initialize(**args) update!(**args) end |
Instance Attribute Details
#schema_version ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Corresponds to the JSON property schemaVersion
7892 7893 7894 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7892 def schema_version @schema_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7899 7900 7901 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 7899 def update!(**args) @schema_version = args[:schema_version] if args.key?(:schema_version) end |