Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

The status of each individual document in the import process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus

Returns a new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus.



8086
8087
8088
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_gcs_sourceString

The source Cloud Storage URI of the document. Corresponds to the JSON property inputGcsSource

Returns:

  • (String)


8069
8070
8071
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8069

def input_gcs_source
  @input_gcs_source
end

#output_document_idGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentId

Document Identifier. Corresponds to the JSON property outputDocumentId



8074
8075
8076
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8074

def output_document_id
  @output_document_id
end

#statusGoogle::Apis::DocumentaiV1beta3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



8084
8085
8086
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8084

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8091
8092
8093
8094
8095
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8091

def update!(**args)
  @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source)
  @output_document_id = args[:output_document_id] if args.key?(:output_document_id)
  @status = args[:status] if args.key?(:status)
end