Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The status of each individual document in the import process.
Instance Attribute Summary collapse
-
#input_gcs_source ⇒ String
The source Cloud Storage URI of the document.
-
#output_document_id ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentId
Document Identifier.
-
#status ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus
constructor
A new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus
Returns a new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataIndividualImportStatus.
8053 8054 8055 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_gcs_source ⇒ String
The source Cloud Storage URI of the document.
Corresponds to the JSON property inputGcsSource
8036 8037 8038 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8036 def input_gcs_source @input_gcs_source end |
#output_document_id ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentId
Document Identifier.
Corresponds to the JSON property outputDocumentId
8041 8042 8043 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8041 def output_document_id @output_document_id end |
#status ⇒ Google::Apis::DocumentaiV1beta3::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
8051 8052 8053 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8051 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8058 8059 8060 8061 8062 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8058 def update!(**args) @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source) @output_document_id = args[:output_document_id] if args.key?(:output_document_id) @status = args[:status] if args.key?(:status) end |