Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Config for importing documents. Each batch can have its own dataset split type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig

Returns a new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfig.



8112
8113
8114
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_split_configGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportDocumentsRequestBatchDocumentsImportConfigAutoSplitConfig

The config for auto-split. Corresponds to the JSON property autoSplitConfig



8091
8092
8093
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8091

def auto_split_config
  @auto_split_config
end

#batch_input_configGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3BatchDocumentsInputConfig

The common config to specify a set of documents used as input. Corresponds to the JSON property batchInputConfig



8096
8097
8098
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8096

def batch_input_config
  @batch_input_config
end

#dataset_splitString

Target dataset split where the documents must be stored. Corresponds to the JSON property datasetSplit

Returns:

  • (String)


8101
8102
8103
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8101

def dataset_split
  @dataset_split
end

#document_typeString

Optional. If set, determines the type of the documents to be imported in this batch. It can be used to auto-label the documents with a single entity of the provided type. This field can only be used with a classifier or splitter processor. Providing this field is mutually exclusive with entities and auto_labeling_config. Corresponds to the JSON property documentType

Returns:

  • (String)


8110
8111
8112
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8110

def document_type
  @document_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8117
8118
8119
8120
8121
8122
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8117

def update!(**args)
  @auto_split_config = args[:auto_split_config] if args.key?(:auto_split_config)
  @batch_input_config = args[:batch_input_config] if args.key?(:batch_input_config)
  @dataset_split = args[:dataset_split] if args.key?(:dataset_split)
  @document_type = args[:document_type] if args.key?(:document_type)
end