Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The request message for the ImportProcessorVersion method. The Document AI Service Agent of the destination project must have Document AI Editor role on the source project. The destination project is specified as part of the parent field. The source project is specified as part of the source or external_processor_version_source field.
Instance Attribute Summary collapse
-
#external_processor_version_source ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequestExternalProcessorVersionSource
The external source processor version.
-
#processor_version_source ⇒ String
The source processor version to import from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequest
constructor
A new instance of GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequest
Returns a new instance of GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequest.
8197 8198 8199 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_processor_version_source ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ImportProcessorVersionRequestExternalProcessorVersionSource
The external source processor version.
Corresponds to the JSON property externalProcessorVersionSource
8189 8190 8191 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8189 def external_processor_version_source @external_processor_version_source end |
#processor_version_source ⇒ String
The source processor version to import from. The source processor version and
destination processor need to be in the same environment and region.
Corresponds to the JSON property processorVersionSource
8195 8196 8197 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8195 def processor_version_source @processor_version_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8202 8203 8204 8205 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8202 def update!(**args) @external_processor_version_source = args[:external_processor_version_source] if args.key?(:external_processor_version_source) @processor_version_source = args[:processor_version_source] if args.key?(:processor_version_source) end |