Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ListDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ListDocumentsRequest

Returns a new instance of GoogleCloudDocumentaiV1beta3ListDocumentsRequest.



8304
8305
8306
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Optional. Query to filter the documents based on https://google.aip.dev/160. ## Currently support query strings are: SplitType=DATASET_SPLIT_TEST| DATASET_SPLIT_TRAIN|DATASET_SPLIT_UNASSIGNED - LabelingState= DOCUMENT_LABELED|DOCUMENT_UNLABELED|DOCUMENT_AUTO_LABELED - DisplayName=\" file_name.pdf\" - EntityType=abc/def - TagName=\"auto-labeling-running\"|\" sampled\" Note: - Only AND, = and != are supported. e.g. DisplayName= file_name AND EntityType!=abc IS supported. - Wildcard * is supported only in DisplayName filter - No duplicate filter keys are allowed, e.g. EntityType=a AND EntityType=b is NOT supported. - String match is case sensitive (for filter DisplayName & EntityType). Corresponds to the JSON property filter

Returns:

  • (String)


8270
8271
8272
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8270

def filter
  @filter
end

#page_sizeFixnum

The maximum number of documents to return. The service may return fewer than this value. If unspecified, at most 20 documents will be returned. The maximum value is 100; values above 100 will be coerced to 100. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


8277
8278
8279
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8277

def page_size
  @page_size
end

#page_tokenString

A page token, received from a previous ListDocuments call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListDocuments must match the call that provided the page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


8284
8285
8286
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8284

def page_token
  @page_token
end

#return_total_sizeBoolean Also known as: return_total_size?

Optional. Controls if the request requires a total size of matched documents. See ListDocumentsResponse.total_size. Enabling this flag may adversely impact performance. Defaults to false. Corresponds to the JSON property returnTotalSize

Returns:

  • (Boolean)


8291
8292
8293
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8291

def return_total_size
  @return_total_size
end

#skipFixnum

Optional. Number of results to skip beginning from the page_token if provided. https://google.aip.dev/158#skipping-results. It must be a non- negative integer. Negative values will be rejected. Note that this is not the number of pages to skip. If this value causes the cursor to move past the end of results, ListDocumentsResponse.document_metadata and ListDocumentsResponse. next_page_token will be empty. Corresponds to the JSON property skip

Returns:

  • (Fixnum)


8302
8303
8304
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8302

def skip
  @skip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8309
8310
8311
8312
8313
8314
8315
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8309

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @return_total_size = args[:return_total_size] if args.key?(:return_total_size)
  @skip = args[:skip] if args.key?(:skip)
end