Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Options for Process API

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessOptions

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessOptions.



8740
8741
8742
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#from_endFixnum

Only process certain pages from the end, same as above. Corresponds to the JSON property fromEnd

Returns:

  • (Fixnum)


8712
8713
8714
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8712

def from_end
  @from_end
end

#from_startFixnum

Only process certain pages from the start. Process all if the document has fewer pages. Corresponds to the JSON property fromStart

Returns:

  • (Fixnum)


8718
8719
8720
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8718

def from_start
  @from_start
end

#individual_page_selectorGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsIndividualPageSelector

A list of individual page numbers. Corresponds to the JSON property individualPageSelector



8723
8724
8725
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8723

def individual_page_selector
  @individual_page_selector
end

#layout_configGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig

Serving config for layout parser processor. Corresponds to the JSON property layoutConfig



8728
8729
8730
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8728

def layout_config
  @layout_config
end

#ocr_configGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3OcrConfig

Config for Document OCR. Corresponds to the JSON property ocrConfig



8733
8734
8735
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8733

def ocr_config
  @ocr_config
end

#schema_overrideGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property schemaOverride



8738
8739
8740
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8738

def schema_override
  @schema_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8745
8746
8747
8748
8749
8750
8751
8752
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8745

def update!(**args)
  @from_end = args[:from_end] if args.key?(:from_end)
  @from_start = args[:from_start] if args.key?(:from_start)
  @individual_page_selector = args[:individual_page_selector] if args.key?(:individual_page_selector)
  @layout_config = args[:layout_config] if args.key?(:layout_config)
  @ocr_config = args[:ocr_config] if args.key?(:ocr_config)
  @schema_override = args[:schema_override] if args.key?(:schema_override)
end