Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Serving config for layout parser processor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig.



8859
8860
8861
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunking_configGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig

Serving config for chunking. Corresponds to the JSON property chunkingConfig



8814
8815
8816
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8814

def chunking_config
  @chunking_config
end

#enable_image_annotationBoolean Also known as: enable_image_annotation?

Optional. Whether to include image annotations in layout parser response. Corresponds to the JSON property enableImageAnnotation

Returns:

  • (Boolean)


8819
8820
8821
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8819

def enable_image_annotation
  @enable_image_annotation
end

#enable_image_extractionBoolean Also known as: enable_image_extraction?

Optional. Whether to extract images in layout parser response. Corresponds to the JSON property enableImageExtraction

Returns:

  • (Boolean)


8825
8826
8827
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8825

def enable_image_extraction
  @enable_image_extraction
end

#enable_llm_layout_parsingBoolean Also known as: enable_llm_layout_parsing?

Optional. Whether to refine PDF layout using LLM. Corresponds to the JSON property enableLlmLayoutParsing

Returns:

  • (Boolean)


8831
8832
8833
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8831

def enable_llm_layout_parsing
  @enable_llm_layout_parsing
end

#enable_table_annotationBoolean Also known as: enable_table_annotation?

Optional. Whether to include table annotations in layout parser response. Corresponds to the JSON property enableTableAnnotation

Returns:

  • (Boolean)


8837
8838
8839
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8837

def enable_table_annotation
  @enable_table_annotation
end

#enable_table_splitBoolean Also known as: enable_table_split?

Optional. Whether to split table. Corresponds to the JSON property enableTableSplit

Returns:

  • (Boolean)


8843
8844
8845
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8843

def enable_table_split
  @enable_table_split
end

#return_bounding_boxesBoolean Also known as: return_bounding_boxes?

Optional. Whether to include bounding boxes in layout parser processor response. Corresponds to the JSON property returnBoundingBoxes

Returns:

  • (Boolean)


8850
8851
8852
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8850

def return_bounding_boxes
  @return_bounding_boxes
end

#return_imagesBoolean Also known as: return_images?

Optional. Whether to include images in layout parser processor response. Corresponds to the JSON property returnImages

Returns:

  • (Boolean)


8856
8857
8858
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8856

def return_images
  @return_images
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8864
8865
8866
8867
8868
8869
8870
8871
8872
8873
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8864

def update!(**args)
  @chunking_config = args[:chunking_config] if args.key?(:chunking_config)
  @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation)
  @enable_image_extraction = args[:enable_image_extraction] if args.key?(:enable_image_extraction)
  @enable_llm_layout_parsing = args[:enable_llm_layout_parsing] if args.key?(:enable_llm_layout_parsing)
  @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation)
  @enable_table_split = args[:enable_table_split] if args.key?(:enable_table_split)
  @return_bounding_boxes = args[:return_bounding_boxes] if args.key?(:return_bounding_boxes)
  @return_images = args[:return_images] if args.key?(:return_images)
end