Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Serving config for layout parser processor.
Instance Attribute Summary collapse
-
#chunking_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig
Serving config for chunking.
-
#enable_image_annotation ⇒ Boolean
(also: #enable_image_annotation?)
Optional.
-
#enable_image_extraction ⇒ Boolean
(also: #enable_image_extraction?)
Optional.
-
#enable_llm_layout_parsing ⇒ Boolean
(also: #enable_llm_layout_parsing?)
Optional.
-
#enable_table_annotation ⇒ Boolean
(also: #enable_table_annotation?)
Optional.
-
#enable_table_split ⇒ Boolean
(also: #enable_table_split?)
Optional.
-
#return_bounding_boxes ⇒ Boolean
(also: #return_bounding_boxes?)
Optional.
-
#return_images ⇒ Boolean
(also: #return_images?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfig.
8826 8827 8828 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8826 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunking_config ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptionsLayoutConfigChunkingConfig
Serving config for chunking.
Corresponds to the JSON property chunkingConfig
8781 8782 8783 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8781 def chunking_config @chunking_config end |
#enable_image_annotation ⇒ Boolean Also known as: enable_image_annotation?
Optional. Whether to include image annotations in layout parser response.
Corresponds to the JSON property enableImageAnnotation
8786 8787 8788 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8786 def enable_image_annotation @enable_image_annotation end |
#enable_image_extraction ⇒ Boolean Also known as: enable_image_extraction?
Optional. Whether to extract images in layout parser response.
Corresponds to the JSON property enableImageExtraction
8792 8793 8794 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8792 def enable_image_extraction @enable_image_extraction end |
#enable_llm_layout_parsing ⇒ Boolean Also known as: enable_llm_layout_parsing?
Optional. Whether to refine PDF layout using LLM.
Corresponds to the JSON property enableLlmLayoutParsing
8798 8799 8800 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8798 def enable_llm_layout_parsing @enable_llm_layout_parsing end |
#enable_table_annotation ⇒ Boolean Also known as: enable_table_annotation?
Optional. Whether to include table annotations in layout parser response.
Corresponds to the JSON property enableTableAnnotation
8804 8805 8806 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8804 def enable_table_annotation @enable_table_annotation end |
#enable_table_split ⇒ Boolean Also known as: enable_table_split?
Optional. Whether to split table.
Corresponds to the JSON property enableTableSplit
8810 8811 8812 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8810 def enable_table_split @enable_table_split end |
#return_bounding_boxes ⇒ Boolean Also known as: return_bounding_boxes?
Optional. Whether to include bounding boxes in layout parser processor
response.
Corresponds to the JSON property returnBoundingBoxes
8817 8818 8819 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8817 def return_bounding_boxes @return_bounding_boxes end |
#return_images ⇒ Boolean Also known as: return_images?
Optional. Whether to include images in layout parser processor response.
Corresponds to the JSON property returnImages
8823 8824 8825 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8823 def return_images @return_images end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8831 def update!(**args) @chunking_config = args[:chunking_config] if args.key?(:chunking_config) @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation) @enable_image_extraction = args[:enable_image_extraction] if args.key?(:enable_image_extraction) @enable_llm_layout_parsing = args[:enable_llm_layout_parsing] if args.key?(:enable_llm_layout_parsing) @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation) @enable_table_split = args[:enable_table_split] if args.key?(:enable_table_split) @return_bounding_boxes = args[:return_bounding_boxes] if args.key?(:return_bounding_boxes) @return_images = args[:return_images] if args.key?(:return_images) end |