Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Request message for the ProcessDocument method.
Instance Attribute Summary collapse
-
#document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI.
-
#field_mask ⇒ String
Specifies which fields to include in the ProcessResponse.document output.
-
#gcs_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GcsDocument
Specifies a document stored on Cloud Storage.
-
#imageless_mode ⇒ Boolean
(also: #imageless_mode?)
Optional.
-
#inline_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI.
-
#labels ⇒ Hash<String,String>
Optional.
-
#process_options ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptions
Options for Process API Corresponds to the JSON property
processOptions. -
#raw_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3RawDocument
Payload message of raw document content (bytes).
-
#skip_human_review ⇒ Boolean
(also: #skip_human_review?)
Whether human review should be skipped for this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessRequest
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessRequest
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessRequest.
8988 8989 8990 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property document
8935 8936 8937 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8935 def document @document end |
#field_mask ⇒ String
Specifies which fields to include in the ProcessResponse.document output. Only
supports top-level document and pages field, so it must be in the form of
document_field_name or pages.page_field_name`.
Corresponds to the JSON propertyfieldMask`
8942 8943 8944 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8942 def field_mask @field_mask end |
#gcs_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GcsDocument
Specifies a document stored on Cloud Storage.
Corresponds to the JSON property gcsDocument
8947 8948 8949 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8947 def gcs_document @gcs_document end |
#imageless_mode ⇒ Boolean Also known as: imageless_mode?
Optional. Option to remove images from the document.
Corresponds to the JSON property imagelessMode
8952 8953 8954 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8952 def imageless_mode @imageless_mode end |
#inline_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property inlineDocument
8961 8962 8963 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8961 def inline_document @inline_document end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. Label keys
and values can be no longer than 63 characters (Unicode codepoints) and can
only contain lowercase letters, numeric characters, underscores, and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter.
Corresponds to the JSON property labels
8970 8971 8972 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8970 def labels @labels end |
#process_options ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptions
Options for Process API
Corresponds to the JSON property processOptions
8975 8976 8977 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8975 def @process_options end |
#raw_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3RawDocument
Payload message of raw document content (bytes).
Corresponds to the JSON property rawDocument
8980 8981 8982 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8980 def raw_document @raw_document end |
#skip_human_review ⇒ Boolean Also known as: skip_human_review?
Whether human review should be skipped for this request. Default to false.
Corresponds to the JSON property skipHumanReview
8985 8986 8987 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8985 def skip_human_review @skip_human_review end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 9003 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8993 def update!(**args) @document = args[:document] if args.key?(:document) @field_mask = args[:field_mask] if args.key?(:field_mask) @gcs_document = args[:gcs_document] if args.key?(:gcs_document) @imageless_mode = args[:imageless_mode] if args.key?(:imageless_mode) @inline_document = args[:inline_document] if args.key?(:inline_document) @labels = args[:labels] if args.key?(:labels) @process_options = args[:process_options] if args.key?(:process_options) @raw_document = args[:raw_document] if args.key?(:raw_document) @skip_human_review = args[:skip_human_review] if args.key?(:skip_human_review) end |