Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Request message for the ProcessDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessRequest

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessRequest.



8981
8982
8983
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property document



8928
8929
8930
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8928

def document
  @document
end

#field_maskString

Specifies which fields to include in the ProcessResponse.document output. Only supports top-level document and pages field, so it must be in the form of document_field_name or pages.page_field_name`. Corresponds to the JSON propertyfieldMask`

Returns:

  • (String)


8935
8936
8937
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8935

def field_mask
  @field_mask
end

#gcs_documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3GcsDocument

Specifies a document stored on Cloud Storage. Corresponds to the JSON property gcsDocument



8940
8941
8942
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8940

def gcs_document
  @gcs_document
end

#imageless_modeBoolean Also known as: imageless_mode?

Optional. Option to remove images from the document. Corresponds to the JSON property imagelessMode

Returns:

  • (Boolean)


8945
8946
8947
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8945

def imageless_mode
  @imageless_mode
end

#inline_documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property inlineDocument



8954
8955
8956
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8954

def inline_document
  @inline_document
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8963
8964
8965
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8963

def labels
  @labels
end

#process_optionsGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessOptions

Options for Process API Corresponds to the JSON property processOptions



8968
8969
8970
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8968

def process_options
  @process_options
end

#raw_documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3RawDocument

Payload message of raw document content (bytes). Corresponds to the JSON property rawDocument



8973
8974
8975
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8973

def raw_document
  @raw_document
end

#skip_human_reviewBoolean Also known as: skip_human_review?

Whether human review should be skipped for this request. Default to false. Corresponds to the JSON property skipHumanReview

Returns:

  • (Boolean)


8978
8979
8980
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8978

def skip_human_review
  @skip_human_review
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8986
8987
8988
8989
8990
8991
8992
8993
8994
8995
8996
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8986

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @field_mask = args[:field_mask] if args.key?(:field_mask)
  @gcs_document = args[:gcs_document] if args.key?(:gcs_document)
  @imageless_mode = args[:imageless_mode] if args.key?(:imageless_mode)
  @inline_document = args[:inline_document] if args.key?(:inline_document)
  @labels = args[:labels] if args.key?(:labels)
  @process_options = args[:process_options] if args.key?(:process_options)
  @raw_document = args[:raw_document] if args.key?(:raw_document)
  @skip_human_review = args[:skip_human_review] if args.key?(:skip_human_review)
end