Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessResponse
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Response message for the ProcessDocument method.
Instance Attribute Summary collapse
-
#document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI.
-
#human_review_operation ⇒ String
The name of the operation triggered by the processed document.
-
#human_review_status ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3HumanReviewStatus
The status of human review on a processed document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessResponse
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessResponse
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessResponse.
8990 8991 8992 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property document
8976 8977 8978 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8976 def document @document end |
#human_review_operation ⇒ String
The name of the operation triggered by the processed document. If the human
review process isn't triggered, this field is empty. It has the same response
type and metadata as the long-running operation returned by ReviewDocument.
Corresponds to the JSON property humanReviewOperation
8983 8984 8985 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8983 def human_review_operation @human_review_operation end |
#human_review_status ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3HumanReviewStatus
The status of human review on a processed document.
Corresponds to the JSON property humanReviewStatus
8988 8989 8990 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8988 def human_review_status @human_review_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8995 8996 8997 8998 8999 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 8995 def update!(**args) @document = args[:document] if args.key?(:document) @human_review_operation = args[:human_review_operation] if args.key?(:human_review_operation) @human_review_status = args[:human_review_status] if args.key?(:human_review_status) end |