Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Processor
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Processor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.
Instance Attribute Summary collapse
-
#active_schema_version ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#default_processor_version ⇒ String
The default processor version.
-
#display_name ⇒ String
The display name of the processor.
-
#kms_key_name ⇒ String
The KMS key used for encryption and decryption in CMEK scenarios.
-
#name ⇒ String
Output only.
-
#process_endpoint ⇒ String
Output only.
-
#processor_version_aliases ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionAlias>
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
The processor type, such as:
OCR_PROCESSOR,INVOICE_PROCESSOR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Processor
constructor
A new instance of GoogleCloudDocumentaiV1beta3Processor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Processor
Returns a new instance of GoogleCloudDocumentaiV1beta3Processor.
9075 9076 9077 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_schema_version ⇒ String
Optional. SchemaVersion used by the Processor. It is the same as Processor's
DatasetSchema.schema_version Format is projects/project/locations/location
/schemas/schema/schemaVersions/schema_version
Corresponds to the JSON propertyactiveSchemaVersion`
9012 9013 9014 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9012 def active_schema_version @active_schema_version end |
#create_time ⇒ String
Output only. The time the processor was created.
Corresponds to the JSON property createTime
9017 9018 9019 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9017 def create_time @create_time end |
#default_processor_version ⇒ String
The default processor version.
Corresponds to the JSON property defaultProcessorVersion
9022 9023 9024 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9022 def default_processor_version @default_processor_version end |
#display_name ⇒ String
The display name of the processor.
Corresponds to the JSON property displayName
9027 9028 9029 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9027 def display_name @display_name end |
#kms_key_name ⇒ String
The KMS key used for
encryption and decryption in CMEK scenarios.
Corresponds to the JSON property kmsKeyName
9033 9034 9035 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9033 def kms_key_name @kms_key_name end |
#name ⇒ String
Output only. Immutable. The resource name of the processor. Format: projects/
project/locations/location/processors/processor`
Corresponds to the JSON propertyname`
9039 9040 9041 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9039 def name @name end |
#process_endpoint ⇒ String
Output only. Immutable. The http endpoint that can be called to invoke
processing.
Corresponds to the JSON property processEndpoint
9045 9046 9047 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9045 def process_endpoint @process_endpoint end |
#processor_version_aliases ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionAlias>
Output only. The processor version aliases.
Corresponds to the JSON property processorVersionAliases
9050 9051 9052 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9050 def processor_version_aliases @processor_version_aliases end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
9055 9056 9057 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9055 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
9061 9062 9063 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9061 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of the processor.
Corresponds to the JSON property state
9067 9068 9069 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9067 def state @state end |
#type ⇒ String
The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR. To get a
list of processor types, see FetchProcessorTypes.
Corresponds to the JSON property type
9073 9074 9075 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9073 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9080 def update!(**args) @active_schema_version = args[:active_schema_version] if args.key?(:active_schema_version) @create_time = args[:create_time] if args.key?(:create_time) @default_processor_version = args[:default_processor_version] if args.key?(:default_processor_version) @display_name = args[:display_name] if args.key?(:display_name) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @name = args[:name] if args.key?(:name) @process_endpoint = args[:process_endpoint] if args.key?(:process_endpoint) @processor_version_aliases = args[:processor_version_aliases] if args.key?(:processor_version_aliases) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |