Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorType
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
A processor type is responsible for performing a certain document understanding task on a certain type of document.
Instance Attribute Summary collapse
-
#allow_creation ⇒ Boolean
(also: #allow_creation?)
Whether the processor type allows creation.
-
#available_locations ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorTypeLocationInfo>
The locations in which this processor is available.
-
#category ⇒ String
The processor category, used by UI to group processor types.
-
#launch_stage ⇒ String
Launch stage of the processor type Corresponds to the JSON property
launchStage. -
#name ⇒ String
The resource name of the processor type.
-
#sample_document_uris ⇒ Array<String>
A set of Cloud Storage URIs of sample documents for this processor.
-
#type ⇒ String
The processor type, such as:
OCR_PROCESSOR,INVOICE_PROCESSOR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorType
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessorType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorType
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorType.
9139 9140 9141 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_creation ⇒ Boolean Also known as: allow_creation?
Whether the processor type allows creation. If true, users can create a
processor of this processor type. Otherwise, users need to request access.
Corresponds to the JSON property allowCreation
9105 9106 9107 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9105 def allow_creation @allow_creation end |
#available_locations ⇒ Array<Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorTypeLocationInfo>
The locations in which this processor is available.
Corresponds to the JSON property availableLocations
9111 9112 9113 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9111 def available_locations @available_locations end |
#category ⇒ String
The processor category, used by UI to group processor types.
Corresponds to the JSON property category
9116 9117 9118 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9116 def category @category end |
#launch_stage ⇒ String
Launch stage of the processor type
Corresponds to the JSON property launchStage
9121 9122 9123 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9121 def launch_stage @launch_stage end |
#name ⇒ String
The resource name of the processor type. Format: projects/project/
processorTypes/processor_type`
Corresponds to the JSON propertyname`
9127 9128 9129 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9127 def name @name end |
#sample_document_uris ⇒ Array<String>
A set of Cloud Storage URIs of sample documents for this processor.
Corresponds to the JSON property sampleDocumentUris
9132 9133 9134 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9132 def sample_document_uris @sample_document_uris end |
#type ⇒ String
The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR.
Corresponds to the JSON property type
9137 9138 9139 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9137 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9144 9145 9146 9147 9148 9149 9150 9151 9152 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9144 def update!(**args) @allow_creation = args[:allow_creation] if args.key?(:allow_creation) @available_locations = args[:available_locations] if args.key?(:available_locations) @category = args[:category] if args.key?(:category) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @name = args[:name] if args.key?(:name) @sample_document_uris = args[:sample_document_uris] if args.key?(:sample_document_uris) @type = args[:type] if args.key?(:type) end |