Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersion
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deprecation_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo
Information about the upcoming deprecation of this processor version.
-
#display_name ⇒ String
The display name of the processor version.
-
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
-
#gen_ai_model_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo
Information about Generative AI model-based processor versions.
-
#google_managed ⇒ Boolean
(also: #google_managed?)
Output only.
-
#kms_key_name ⇒ String
Output only.
-
#kms_key_version_name ⇒ String
Output only.
-
#latest_evaluation ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationReference
Gives a short summary of an evaluation, and links to the evaluation itself.
-
#model_type ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersion
constructor
A new instance of GoogleCloudDocumentaiV1beta3ProcessorVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersion
Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersion.
9290 9291 9292 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the processor version was created.
Corresponds to the JSON property createTime
9218 9219 9220 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9218 def create_time @create_time end |
#deprecation_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionDeprecationInfo
Information about the upcoming deprecation of this processor version.
Corresponds to the JSON property deprecationInfo
9223 9224 9225 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9223 def deprecation_info @deprecation_info end |
#display_name ⇒ String
The display name of the processor version.
Corresponds to the JSON property displayName
9228 9229 9230 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9228 def display_name @display_name end |
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property documentSchema
9233 9234 9235 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9233 def document_schema @document_schema end |
#gen_ai_model_info ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo
Information about Generative AI model-based processor versions.
Corresponds to the JSON property genAiModelInfo
9238 9239 9240 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9238 def gen_ai_model_info @gen_ai_model_info end |
#google_managed ⇒ Boolean Also known as: google_managed?
Output only. Denotes that this ProcessorVersion is managed by Google.
Corresponds to the JSON property googleManaged
9243 9244 9245 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9243 def google_managed @google_managed end |
#kms_key_name ⇒ String
Output only. The KMS key name used for encryption.
Corresponds to the JSON property kmsKeyName
9249 9250 9251 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9249 def kms_key_name @kms_key_name end |
#kms_key_version_name ⇒ String
Output only. The KMS key version with which data is encrypted.
Corresponds to the JSON property kmsKeyVersionName
9254 9255 9256 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9254 def kms_key_version_name @kms_key_version_name end |
#latest_evaluation ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3EvaluationReference
Gives a short summary of an evaluation, and links to the evaluation itself.
Corresponds to the JSON property latestEvaluation
9259 9260 9261 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9259 def latest_evaluation @latest_evaluation end |
#model_type ⇒ String
Output only. The model type of this processor version.
Corresponds to the JSON property modelType
9264 9265 9266 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9264 def model_type @model_type end |
#name ⇒ String
Identifier. The resource name of the processor version. Format: projects/
project/locations/location/processors/processor/processorVersions/
processor_version`
Corresponds to the JSON propertyname`
9271 9272 9273 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9271 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
9276 9277 9278 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9276 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
9282 9283 9284 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9282 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of the processor version.
Corresponds to the JSON property state
9288 9289 9290 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9288 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9295 9296 9297 9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9295 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deprecation_info = args[:deprecation_info] if args.key?(:deprecation_info) @display_name = args[:display_name] if args.key?(:display_name) @document_schema = args[:document_schema] if args.key?(:document_schema) @gen_ai_model_info = args[:gen_ai_model_info] if args.key?(:gen_ai_model_info) @google_managed = args[:google_managed] if args.key?(:google_managed) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_version_name = args[:kms_key_version_name] if args.key?(:kms_key_version_name) @latest_evaluation = args[:latest_evaluation] if args.key?(:latest_evaluation) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) end |