Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
The long-running operation metadata for the ReviewDocument method.
Instance Attribute Summary collapse
-
#common_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
The common metadata for long running operations.
-
#create_time ⇒ String
The creation time of the operation.
-
#question_id ⇒ String
The Crowd Compute question ID.
-
#state ⇒ String
Used only when Operation.done is false.
-
#state_message ⇒ String
A message providing more details about the current state of processing.
-
#update_time ⇒ String
The last update time of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
constructor
A new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
Returns a new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata.
9525 9526 9527 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_metadata ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
The common metadata for long running operations.
Corresponds to the JSON property commonMetadata
9497 9498 9499 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9497 def @common_metadata end |
#create_time ⇒ String
The creation time of the operation.
Corresponds to the JSON property createTime
9502 9503 9504 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9502 def create_time @create_time end |
#question_id ⇒ String
The Crowd Compute question ID.
Corresponds to the JSON property questionId
9507 9508 9509 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9507 def question_id @question_id end |
#state ⇒ String
Used only when Operation.done is false.
Corresponds to the JSON property state
9512 9513 9514 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9512 def state @state end |
#state_message ⇒ String
A message providing more details about the current state of processing. For
example, the error message if the operation is failed.
Corresponds to the JSON property stateMessage
9518 9519 9520 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9518 def @state_message end |
#update_time ⇒ String
The last update time of the operation.
Corresponds to the JSON property updateTime
9523 9524 9525 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9523 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9530 9531 9532 9533 9534 9535 9536 9537 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9530 def update!(**args) @common_metadata = args[:common_metadata] if args.key?(:common_metadata) @create_time = args[:create_time] if args.key?(:create_time) @question_id = args[:question_id] if args.key?(:question_id) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @update_time = args[:update_time] if args.key?(:update_time) end |