Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ReviewDocumentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Request message for the ReviewDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentRequest

Returns a new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentRequest.



9609
9610
9611
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property document



9583
9584
9585
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9583

def document
  @document
end

#document_schemaGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property documentSchema



9588
9589
9590
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9588

def document_schema
  @document_schema
end

#enable_schema_validationBoolean Also known as: enable_schema_validation?

Whether the validation should be performed on the ad-hoc review request. Corresponds to the JSON property enableSchemaValidation

Returns:

  • (Boolean)


9593
9594
9595
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9593

def enable_schema_validation
  @enable_schema_validation
end

#inline_documentGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property inlineDocument



9602
9603
9604
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9602

def inline_document
  @inline_document
end

#priorityString

The priority of the human review task. Corresponds to the JSON property priority

Returns:

  • (String)


9607
9608
9609
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9607

def priority
  @priority
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9614
9615
9616
9617
9618
9619
9620
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9614

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @document_schema = args[:document_schema] if args.key?(:document_schema)
  @enable_schema_validation = args[:enable_schema_validation] if args.key?(:enable_schema_validation)
  @inline_document = args[:inline_document] if args.key?(:inline_document)
  @priority = args[:priority] if args.key?(:priority)
end