Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ReviewDocumentRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3ReviewDocumentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
Request message for the ReviewDocument method.
Instance Attribute Summary collapse
-
#document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI.
-
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
-
#enable_schema_validation ⇒ Boolean
(also: #enable_schema_validation?)
Whether the validation should be performed on the ad-hoc review request.
-
#inline_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI.
-
#priority ⇒ String
The priority of the human review task.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentRequest
constructor
A new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentRequest
Returns a new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentRequest.
9576 9577 9578 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property document
9550 9551 9552 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9550 def document @document end |
#document_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property documentSchema
9555 9556 9557 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9555 def document_schema @document_schema end |
#enable_schema_validation ⇒ Boolean Also known as: enable_schema_validation?
Whether the validation should be performed on the ad-hoc review request.
Corresponds to the JSON property enableSchemaValidation
9560 9561 9562 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9560 def enable_schema_validation @enable_schema_validation end |
#inline_document ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property inlineDocument
9569 9570 9571 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9569 def inline_document @inline_document end |
#priority ⇒ String
The priority of the human review task.
Corresponds to the JSON property priority
9574 9575 9576 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9574 def priority @priority end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9581 9582 9583 9584 9585 9586 9587 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9581 def update!(**args) @document = args[:document] if args.key?(:document) @document_schema = args[:document_schema] if args.key?(:document_schema) @enable_schema_validation = args[:enable_schema_validation] if args.key?(:enable_schema_validation) @inline_document = args[:inline_document] if args.key?(:inline_document) @priority = args[:priority] if args.key?(:priority) end |