Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaGenerationIteration
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaGenerationIteration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb
Overview
A single iteration of the schema generation.
Instance Attribute Summary collapse
-
#adjusted_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
-
#generated_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
-
#prompt ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3SchemaGenerationIteration
constructor
A new instance of GoogleCloudDocumentaiV1beta3SchemaGenerationIteration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3SchemaGenerationIteration
Returns a new instance of GoogleCloudDocumentaiV1beta3SchemaGenerationIteration.
9693 9694 9695 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adjusted_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Corresponds to the JSON property adjustedSchema
9681 9682 9683 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9681 def adjusted_schema @adjusted_schema end |
#generated_schema ⇒ Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Corresponds to the JSON property generatedSchema
9686 9687 9688 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9686 def generated_schema @generated_schema end |
#prompt ⇒ String
Optional. The prompt used for the iteration.
Corresponds to the JSON property prompt
9691 9692 9693 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9691 def prompt @prompt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9698 9699 9700 9701 9702 |
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9698 def update!(**args) @adjusted_schema = args[:adjusted_schema] if args.key?(:adjusted_schema) @generated_schema = args[:generated_schema] if args.key?(:generated_schema) @prompt = args[:prompt] if args.key?(:prompt) end |