Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3SchemaVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

SchemaVersion is a version of the Schema which is created in SchemaGroup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3SchemaVersion

Returns a new instance of GoogleCloudDocumentaiV1beta3SchemaVersion.



9735
9736
9737
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the SchemaVersion was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9712
9713
9714
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9712

def create_time
  @create_time
end

#display_nameString

Required. The user-defined name of the SchemaVersion. Corresponds to the JSON property displayName

Returns:

  • (String)


9717
9718
9719
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9717

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. The GCP labels for the SchemaVersion. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


9722
9723
9724
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9722

def labels
  @labels
end

#nameString

Identifier. The resource name of the SchemaVersion. Format: projects/project /locations/location/schemas/schema/schemaVersions/schema_version` Corresponds to the JSON propertyname`

Returns:

  • (String)


9728
9729
9730
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9728

def name
  @name
end

#schemaGoogle::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property schema



9733
9734
9735
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9733

def schema
  @schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9740
9741
9742
9743
9744
9745
9746
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9740

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
end