Class: Google::Apis::DocumentaiV1beta3::GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestFoundationModelTuningOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Options to control foundation model tuning of the processor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestFoundationModelTuningOptions

Returns a new instance of GoogleCloudDocumentaiV1beta3TrainProcessorVersionRequestFoundationModelTuningOptions.



9993
9994
9995
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#learning_rate_multiplierFloat

Optional. The multiplier to apply to the recommended learning rate. Valid values are between 0.1 and 10. If not provided, recommended learning rate will be used. Corresponds to the JSON property learningRateMultiplier

Returns:

  • (Float)


9985
9986
9987
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9985

def learning_rate_multiplier
  @learning_rate_multiplier
end

#train_stepsFixnum

Optional. The number of steps to run for model tuning. Valid values are between 1 and 400. If not provided, recommended steps will be used. Corresponds to the JSON property trainSteps

Returns:

  • (Fixnum)


9991
9992
9993
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9991

def train_steps
  @train_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9998
9999
10000
10001
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 9998

def update!(**args)
  @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier)
  @train_steps = args[:train_steps] if args.key?(:train_steps)
end