Class: Google::Apis::DocumentaiV1beta3::GoogleTypePostalAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1beta3/classes.rb,
lib/google/apis/documentai_v1beta3/representations.rb,
lib/google/apis/documentai_v1beta3/representations.rb

Overview

Represents a postal address, such as for postal delivery or payments addresses. With a postal address, a postal service can deliver items to a premise, P.O. box, or similar. A postal address is not intended to model geographical locations like roads, towns, or mountains. In typical usage, an address would be created by user input or from importing existing data, depending on the type of process. Advice on address input or editing: - Use an internationalization-ready address widget such as https://github.com/google/ libaddressinput. - Users should not be presented with UI elements for input or editing of fields outside countries where that field is used. For more guidance on how to use this schema, see: https://support.google.com/business/ answer/6397478.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleTypePostalAddress

Returns a new instance of GoogleTypePostalAddress.



10749
10750
10751
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#address_linesArray<String>

Unstructured address lines describing the lower levels of an address. Because values in address_lines do not have type information and may sometimes contain multiple values in a single field (for example, "Austin, TX"), it is important that the line order is clear. The order of address lines should be " envelope order" for the country or region of the address. In places where this can vary (for example, Japan), address_language is used to make it explicit ( for example, "ja" for large-to-small ordering and "ja-Latn" or "en" for small- to-large). In this way, the most specific line of an address can be selected based on the language. The minimum permitted structural representation of an address consists of a region_code with all remaining information placed in the address_lines. It would be possible to format such an address very approximately without geocoding, but no semantic reasoning could be made about any of the address components until it was at least partially resolved. Creating an address only containing a region_code and address_lines and then geocoding is the recommended way to handle completely unstructured addresses (as opposed to guessing which parts of the address should be localities or administrative areas). Corresponds to the JSON property addressLines

Returns:

  • (Array<String>)


10667
10668
10669
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10667

def address_lines
  @address_lines
end

#administrative_areaString

Optional. Highest administrative subdivision which is used for postal addresses of a country or region. For example, this can be a state, a province, an oblast, or a prefecture. For Spain, this is the province and not the autonomous community (for example, "Barcelona" and not "Catalonia"). Many countries don't use an administrative area in postal addresses. For example, in Switzerland, this should be left unpopulated. Corresponds to the JSON property administrativeArea

Returns:

  • (String)


10677
10678
10679
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10677

def administrative_area
  @administrative_area
end

#language_codeString

Optional. BCP-47 language code of the contents of this address (if known). This is often the UI language of the input form or is expected to match one of the languages used in the address' country/region, or their transliterated equivalents. This can affect formatting in certain countries, but is not critical to the correctness of the data and will never affect any validation or other non-formatting related operations. If this value is not known, it should be omitted (rather than specifying a possibly incorrect default). Examples: "zh-Hant", "ja", "ja-Latn", "en". Corresponds to the JSON property languageCode

Returns:

  • (String)


10689
10690
10691
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10689

def language_code
  @language_code
end

#localityString

Optional. Generally refers to the city or town portion of the address. Examples: US city, IT comune, UK post town. In regions of the world where localities are not well defined or do not fit into this structure well, leave locality empty and use address_lines. Corresponds to the JSON property locality

Returns:

  • (String)


10697
10698
10699
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10697

def locality
  @locality
end

#organizationString

Optional. The name of the organization at the address. Corresponds to the JSON property organization

Returns:

  • (String)


10702
10703
10704
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10702

def organization
  @organization
end

#postal_codeString

Optional. Postal code of the address. Not all countries use or require postal codes to be present, but where they are used, they may trigger additional validation with other parts of the address (for example, state or zip code validation in the United States). Corresponds to the JSON property postalCode

Returns:

  • (String)


10710
10711
10712
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10710

def postal_code
  @postal_code
end

#recipientsArray<String>

Optional. The recipient at the address. This field may, under certain circumstances, contain multiline information. For example, it might contain " care of" information. Corresponds to the JSON property recipients

Returns:

  • (Array<String>)


10717
10718
10719
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10717

def recipients
  @recipients
end

#region_codeString

Required. CLDR region code of the country/region of the address. This is never inferred and it is up to the user to ensure the value is correct. See https:// cldr.unicode.org/ and https://www.unicode.org/cldr/charts/30/supplemental/ territory_information.html for details. Example: "CH" for Switzerland. Corresponds to the JSON property regionCode

Returns:

  • (String)


10725
10726
10727
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10725

def region_code
  @region_code
end

#revisionFixnum

The schema revision of the PostalAddress. This must be set to 0, which is the latest revision. All new revisions must be backward compatible with old revisions. Corresponds to the JSON property revision

Returns:

  • (Fixnum)


10732
10733
10734
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10732

def revision
  @revision
end

#sorting_codeString

Optional. Additional, country-specific, sorting code. This is not used in most regions. Where it is used, the value is either a string like "CEDEX", optionally followed by a number (for example, "CEDEX 7"), or just a number alone, representing the "sector code" (Jamaica), "delivery area indicator" ( Malawi) or "post office indicator" (Côte d'Ivoire). Corresponds to the JSON property sortingCode

Returns:

  • (String)


10741
10742
10743
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10741

def sorting_code
  @sorting_code
end

#sublocalityString

Optional. Sublocality of the address. For example, this can be a neighborhood, borough, or district. Corresponds to the JSON property sublocality

Returns:

  • (String)


10747
10748
10749
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10747

def sublocality
  @sublocality
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
# File 'lib/google/apis/documentai_v1beta3/classes.rb', line 10754

def update!(**args)
  @address_lines = args[:address_lines] if args.key?(:address_lines)
  @administrative_area = args[:administrative_area] if args.key?(:administrative_area)
  @language_code = args[:language_code] if args.key?(:language_code)
  @locality = args[:locality] if args.key?(:locality)
  @organization = args[:organization] if args.key?(:organization)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @recipients = args[:recipients] if args.key?(:recipients)
  @region_code = args[:region_code] if args.key?(:region_code)
  @revision = args[:revision] if args.key?(:revision)
  @sorting_code = args[:sorting_code] if args.key?(:sorting_code)
  @sublocality = args[:sublocality] if args.key?(:sublocality)
end